/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
*/
/* First off, code is included that follows the "include" declaration
** in the input grammar file. */
#include <stdio.h>
#line 53 "parse.y"

#include "sqliteInt.h"

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of this structure is used to store the LIKE,
** GLOB, NOT LIKE, and NOT GLOB operators.
*/
struct LikeOp {
  Token eOperator;  /* "like" or "glob" or "regexp" */
  int not;         /* True if the NOT keyword is present */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** An instance of this structure holds the ATTACH key and the key type.
*/
struct AttachKey { int type;  Token key; };

#line 46 "parse.c"
/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash 
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    sqlite3ParserTOKENTYPE     is the data type used for minor tokens given 
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is sqlite3ParserTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlite3ParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlite3ParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlite3ParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlite3ParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned short int
#define YYNOCODE 252
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 65
#define sqlite3ParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlite3ParserTOKENTYPE yy0;
  Expr* yy72;
  TriggerStep* yy145;
  ExprList* yy148;
  SrcList* yy185;
  int yy194;
  Select* yy243;
  IdList* yy254;
  struct TrigEvent yy332;
  struct LimitVal yy354;
  struct LikeOp yy392;
  struct {int value; int mask;} yy497;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlite3ParserARG_SDECL Parse *pParse;
#define sqlite3ParserARG_PDECL ,Parse *pParse
#define sqlite3ParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlite3ParserARG_STORE yypParser->pParse = pParse
#define YYNSTATE 613
#define YYNRULE 321
#define YYFALLBACK 1
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

/* The yyzerominor constant is used to initialize instances of
** YYMINORTYPE objects to zero. */
static const YYMINORTYPE yyzerominor = { 0 };


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
static const YYACTIONTYPE yy_action[] = {
 /*     0 */   304,  935,  176,  612,    2,  150,  214,  438,   24,   24,
 /*    10 */    24,   24,  487,   26,   26,   26,   26,   27,   27,   28,
 /*    20 */    28,   28,   29,  216,  412,  413,  212,  412,  413,  445,
 /*    30 */   451,   31,   26,   26,   26,   26,   27,   27,   28,   28,
 /*    40 */    28,   29,  216,   30,  482,   32,  134,   23,   22,  308,
 /*    50 */   455,  456,  452,  452,   25,   25,   24,   24,   24,   24,
 /*    60 */   435,   26,   26,   26,   26,   27,   27,   28,   28,   28,
 /*    70 */    29,  216,  304,  216,  311,  438,  511,  489,   45,   26,
 /*    80 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*    90 */   412,  413,  415,  416,  156,  415,  416,  360,  363,  364,
 /*   100 */   311,  445,  451,  385,  513,   21,  186,  494,  365,   27,
 /*   110 */    27,   28,   28,   28,   29,  216,  412,  413,  414,   23,
 /*   120 */    22,  308,  455,  456,  452,  452,   25,   25,   24,   24,
 /*   130 */    24,   24,  554,   26,   26,   26,   26,   27,   27,   28,
 /*   140 */    28,   28,   29,  216,  304,  228,  503,  135,  467,  218,
 /*   150 */   438,  145,  132,  256,  358,  261,  359,  153,  415,  416,
 /*   160 */   553,  528,  331,   30,  265,   32,  134,  552,  592,  593,
 /*   170 */   230,  228,  489,  445,  451,   57,  505,  328,  132,  256,
 /*   180 */   358,  261,  359,  153,  415,  416,  434,   78,  407,  404,
 /*   190 */   265,   23,   22,  308,  455,  456,  452,  452,   25,   25,
 /*   200 */    24,   24,   24,   24,  476,   26,   26,   26,   26,   27,
 /*   210 */    27,   28,   28,   28,   29,  216,  304,  572,  438,  546,
 /*   220 */   477,  127,  547,  596,   30,  331,   32,  134,  345,  214,
 /*   230 */   428,   63,  331,  355,  414,  478,  241,  341,  414,  342,
 /*   240 */   328,  387,  193,  595,  594,  445,  451,  328,  299,  434,
 /*   250 */    85,  469,  545,  200,  190,  555,  434,   78,  309,  462,
 /*   260 */   463,  571,  471,   23,   22,  308,  455,  456,  452,  452,
 /*   270 */    25,   25,   24,   24,   24,   24,  435,   26,   26,   26,
 /*   280 */    26,   27,   27,   28,   28,   28,   29,  216,  304,  347,
 /*   290 */   221,  191,  512,  429,  544,  331,  440,  234,  345,  430,
 /*   300 */   324,  409,  541,  344,  591,  217,  213,  541,  112,  331,
 /*   310 */   328,  388,  282,  281,  211,   29,  216,  445,  451,  434,
 /*   320 */    79,  217,  214,  334,  328,  458,  458,  442,  442,  442,
 /*   330 */   571,  270,    4,  434,   85,   23,   22,  308,  455,  456,
 /*   340 */   452,  452,   25,   25,   24,   24,   24,   24,  435,   26,
 /*   350 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*   360 */   304,  514,  156,  331,  488,  360,  363,  364,  331,  353,
 /*   370 */   431,  247,  395,  274,  220,  272,  365,  352,  328,  331,
 /*   380 */   388,  282,  281,  328,  412,  413,  307,  434,   93,  445,
 /*   390 */   451,  214,  434,   93,  328,  530,  150,    1,  438,  403,
 /*   400 */   468,  412,  413,  434,   78,   40,  210,   23,   22,  308,
 /*   410 */   455,  456,  452,  452,   25,   25,   24,   24,   24,   24,
 /*   420 */   194,   26,   26,   26,   26,   27,   27,   28,   28,   28,
 /*   430 */    29,  216,  304,  319,  331,  596,  507,  535,  320,  179,
 /*   440 */   435,  489,  467,  156,  192,  349,  360,  363,  364,  328,
 /*   450 */   414,  536,  415,  416,  435,  595,  546,  365,  434,   71,
 /*   460 */   378,  445,  451,  208,  240,  381,  438,  556,   63,  415,
 /*   470 */   416,  414,   28,   28,   28,   29,  216,   43,  435,   23,
 /*   480 */    22,  308,  455,  456,  452,  452,   25,   25,   24,   24,
 /*   490 */    24,   24,  276,   26,   26,   26,   26,   27,   27,   28,
 /*   500 */    28,   28,   29,  216,  304,  354,  209,  414,  510,  412,
 /*   510 */   413,  135,  426,  331,  412,  413,  398,  217,   66,  333,
 /*   520 */   328,  564,  412,  413,   30,  563,   32,  134,  328,  434,
 /*   530 */     8,  546,  484,  445,  451,  400,  489,  434,   72,  377,
 /*   540 */   435,  485,  603,   63,  598,  494,  414,  372,  469,  337,
 /*   550 */   200,   23,   22,  308,  455,  456,  452,  452,   25,   25,
 /*   560 */    24,   24,   24,   24,  386,   26,   26,   26,   26,   27,
 /*   570 */    27,   28,   28,   28,   29,  216,  304,  415,  416,  476,
 /*   580 */   527,   60,  415,  416,  222,  402,  389,  498,  185,  331,
 /*   590 */   415,  416,  385,  242,  331,  477,  331,  506,  453,  336,
 /*   600 */   462,  463,  414,  490,  328,  445,  451,  414,  491,  328,
 /*   610 */   478,  328,  518,  434,   67,  613,  407,  404,  434,   76,
 /*   620 */   434,   97,  519,   23,   22,  308,  455,  456,  452,  452,
 /*   630 */    25,   25,   24,   24,   24,   24,  331,   26,   26,   26,
 /*   640 */    26,   27,   27,   28,   28,   28,   29,  216,  304,  331,
 /*   650 */   310,  328,  268,  368,   64,  331,  397,  439,  438,  233,
 /*   660 */   434,   96,  217,   16,  328,  183,  331,  459,  467,  218,
 /*   670 */   328,  446,  447,  434,  101,  214,  154,  445,  451,  434,
 /*   680 */    99,  328,  464,  154,  566,  466,  334,  396,  458,  458,
 /*   690 */   434,  104,  449,  450,  205,   23,   22,  308,  455,  456,
 /*   700 */   452,  452,   25,   25,   24,   24,   24,   24,  331,   26,
 /*   710 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*   720 */   304,  448,  331,  328,  390,   56,  438,  331,  435,  331,
 /*   730 */   248,  306,  434,  105,  516,  517,  472,  328,  306,   39,
 /*   740 */   331,   41,  328,  265,  328,  414,  434,  126,  339,  445,
 /*   750 */   451,  434,  128,  434,   59,  328,  334,  250,  458,  458,
 /*   760 */   196,  569,  517,  568,  434,  102,  483,   23,   22,  308,
 /*   770 */   455,  456,  452,  452,   25,   25,   24,   24,   24,   24,
 /*   780 */   331,   26,   26,   26,   26,   27,   27,   28,   28,   28,
 /*   790 */    29,  216,  304,  331,  435,  328,  562,  375,  562,  331,
 /*   800 */   264,  858,  606,  303,  434,   77,  197,  137,  328,  406,
 /*   810 */     2,  331,  178,  215,  328,  414,  486,  434,  100,  136,
 /*   820 */    18,  445,  451,  434,   68,  334,  328,  458,  458,  610,
 /*   830 */   926,  460,  926,   65,  414,  434,   98,  314,  528,   23,
 /*   840 */    22,  308,  455,  456,  452,  452,   25,   25,   24,   24,
 /*   850 */    24,   24,  331,   26,   26,   26,   26,   27,   27,   28,
 /*   860 */    28,   28,   29,  216,  304,  331,  350,  328,  264,  155,
 /*   870 */   264,  331,  607,  331,  201,  137,  434,  129,  433,  574,
 /*   880 */   328,  414,  432,  414,  331,  414,  328,  498,  328,  434,
 /*   890 */   130,  498,  539,  445,  451,  434,  131,  434,   69,  328,
 /*   900 */   362,  334,  414,  458,  458,  229,  414,  315,  434,   80,
 /*   910 */   259,   23,   33,  308,  455,  456,  452,  452,   25,   25,
 /*   920 */    24,   24,   24,   24,  331,   26,   26,   26,   26,   27,
 /*   930 */    27,   28,   28,   28,   29,  216,  304,  331,  264,  328,
 /*   940 */   164,  264,  356,  331,  417,  418,  419,  525,  434,   81,
 /*   950 */   376,  542,  328,  414,  318,  331,  414,  538,  328,  465,
 /*   960 */   465,  434,   70,  322,  175,  445,  451,  434,   82,  433,
 /*   970 */   328,  610,  925,  432,  925,  316,  540,  494,  317,  434,
 /*   980 */    83,  522,  523,  587,   22,  308,  455,  456,  452,  452,
 /*   990 */    25,   25,   24,   24,   24,   24,  331,   26,   26,   26,
 /*  1000 */    26,   27,   27,   28,   28,   28,   29,  216,  304,  331,
 /*  1010 */   209,  328,  257,  249,  607,  331,  252,  202,  203,  204,
 /*  1020 */   434,   84,  290,  258,  328,  532,  531,  331,  414,  394,
 /*  1030 */   328,  331,  533,  434,   86,  332,  141,  445,  451,  434,
 /*  1040 */    87,   47,  328,  496,  435,  151,  328,  537,  410,  155,
 /*  1050 */   414,  434,   88,  534,  494,  434,   73,  308,  455,  456,
 /*  1060 */   452,  452,   25,   25,   24,   24,   24,   24,  386,   26,
 /*  1070 */    26,   26,   26,   27,   27,   28,   28,   28,   29,  216,
 /*  1080 */    35,  338,  286,    3,  331,  411,  331,  327,  413,  423,
 /*  1090 */   382,  422,  276,  254,  420,   35,  338,  335,    3,  328,
 /*  1100 */   414,  328,  327,  413,  414,  313,  276,  414,  434,   74,
 /*  1110 */   434,   89,  335,  331,  421,  340,  424,  331,  425,  331,
 /*  1120 */   267,  414,  155,  142,  289,  471,  287,  325,  328,  326,
 /*  1130 */   340,  414,  328,  414,  328,  581,  276,  434,   90,  144,
 /*  1140 */   471,  434,   91,  434,   92,   38,   37,   15,  331,  277,
 /*  1150 */   133,  414,  441,  276,   36,  329,  330,    6,  436,  440,
 /*  1160 */    38,   37,  504,  328,  206,  414,   47,  414,  414,   36,
 /*  1170 */   329,  330,  434,   75,  440,  198,  367,  214,  155,  583,
 /*  1180 */   235,  236,  237,  143,  239,  348,  343,  580,   46,  243,
 /*  1190 */   442,  442,  442,  443,  444,    9,  584,  276,  435,    7,
 /*  1200 */   172,  414,  294,  331,  288,  442,  442,  442,  443,  444,
 /*  1210 */     9,  295,  414,   35,  338,  567,    3,  155,  328,  480,
 /*  1220 */   327,  413,  331,  170,  276,  571,  244,  434,   17,  169,
 /*  1230 */   335,   19,  171,  245,  414,  412,  413,  328,  331,  414,
 /*  1240 */   585,  276,  575,  576,  151,   54,  434,   94,  340,  493,
 /*  1250 */   497,  499,  346,  328,  276,  262,  414,  529,  471,  263,
 /*  1260 */   246,   20,  434,   95,  414,  414,  414,  231,  548,  414,
 /*  1270 */   414,  437,  414,  471,  414,  393,  291,  281,   38,   37,
 /*  1280 */   588,  305,   54,  414,  232,  269,  214,   36,  329,  330,
 /*  1290 */   219,  271,  440,  188,  189,  273,  275,  292,   42,  280,
 /*  1300 */   414,  380,  383,  512,  384,  283,  414,  440,  149,  399,
 /*  1310 */   414,  414,  608,  605,  414,  302,  414,  414,  284,  414,
 /*  1320 */   414,  285,  579,  442,  442,  442,  443,  444,    9,   48,
 /*  1330 */   590,  293,  296,  414,  297,  602,  414,  414,  442,  442,
 /*  1340 */   442,  251,  351,  481,  177,  414,  414,  414,  495,  414,
 /*  1350 */   414,  501,  253,  255,  609,  502,  357,  312,  521,  515,
 /*  1360 */   107,  525,  226,  225,  520,  260,  369,  158,  227,  524,
 /*  1370 */   557,  526,  300,  549,  550,  551,  373,  278,  159,  301,
 /*  1380 */   543,  371,  160,   51,  207,  559,  560,  161,  140,  379,
 /*  1390 */   570,  163,  117,  391,  181,  392,  118,  119,  120,  121,
 /*  1400 */   321,  123,  577,  599,  600,   55,   58,  586,  601,  604,
 /*  1410 */    62,  323,  408,  103,  224,  111,  174,  238,  427,  199,
 /*  1420 */   654,  655,  656,  146,  147,  454,  457,   34,  182,  180,
 /*  1430 */   461,  470,  473,  474,  195,    5,  492,  475,  148,  479,
 /*  1440 */    44,  106,   10,   11,  138,  508,  509,  500,  223,   49,
 /*  1450 */   361,  108,  152,  266,  109,   50,  110,  157,  258,  370,
 /*  1460 */   184,  558,  139,  113,  151,  162,  279,  115,  374,   14,
 /*  1470 */   573,  116,  165,   52,   12,  366,  166,   53,  578,  167,
 /*  1480 */   582,  168,  114,  124,  122,  561,  565,   13,   61,  125,
 /*  1490 */   597,  173,  298,  187,  589,  405,  936,  611,  936,  936,
 /*  1500 */   401,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */    19,  142,  143,  144,  145,   24,  116,   26,   75,   76,
 /*    10 */    77,   78,   25,   80,   81,   82,   83,   84,   85,   86,
 /*    20 */    87,   88,   89,   90,   26,   27,  160,   26,   27,   48,
 /*    30 */    49,   79,   80,   81,   82,   83,   84,   85,   86,   87,
 /*    40 */    88,   89,   90,  222,  223,  224,  225,   66,   67,   68,
 /*    50 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*    60 */   194,   80,   81,   82,   83,   84,   85,   86,   87,   88,
 /*    70 */    89,   90,   19,   90,   19,   94,  174,   25,   25,   80,
 /*    80 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*    90 */    26,   27,   94,   95,   96,   94,   95,   99,  100,  101,
 /*   100 */    19,   48,   49,  150,  174,   52,  119,  166,  110,   84,
 /*   110 */    85,   86,   87,   88,   89,   90,   26,   27,  165,   66,
 /*   120 */    67,   68,   69,   70,   71,   72,   73,   74,   75,   76,
 /*   130 */    77,   78,  186,   80,   81,   82,   83,   84,   85,   86,
 /*   140 */    87,   88,   89,   90,   19,   90,  205,   95,   84,   85,
 /*   150 */    26,   96,   97,   98,   99,  100,  101,  102,   94,   95,
 /*   160 */   181,  182,  150,  222,  109,  224,  225,  188,  104,  105,
 /*   170 */   217,   90,  120,   48,   49,   50,   86,  165,   97,   98,
 /*   180 */    99,  100,  101,  102,   94,   95,  174,  175,    1,    2,
 /*   190 */   109,   66,   67,   68,   69,   70,   71,   72,   73,   74,
 /*   200 */    75,   76,   77,   78,   12,   80,   81,   82,   83,   84,
 /*   210 */    85,   86,   87,   88,   89,   90,   19,   11,   94,  150,
 /*   220 */    28,   24,  186,  150,  222,  150,  224,  225,  216,  116,
 /*   230 */   161,  162,  150,  221,  165,   43,  195,   45,  165,  191,
 /*   240 */   165,  128,  160,  170,  171,   48,   49,  165,  163,  174,
 /*   250 */   175,  166,  167,  168,  185,  186,  174,  175,  169,  170,
 /*   260 */   171,   55,   64,   66,   67,   68,   69,   70,   71,   72,
 /*   270 */    73,   74,   75,   76,   77,   78,  194,   80,   81,   82,
 /*   280 */    83,   84,   85,   86,   87,   88,   89,   90,   19,  214,
 /*   290 */   215,   25,   94,  172,  173,  150,   98,  148,  216,  173,
 /*   300 */   146,  147,  181,  221,  231,  232,  152,  181,  154,  150,
 /*   310 */   165,  105,  106,  107,  160,   89,   90,   48,   49,  174,
 /*   320 */   175,  232,  116,  112,  165,  114,  115,  129,  130,  131,
 /*   330 */    55,   16,  196,  174,  175,   66,   67,   68,   69,   70,
 /*   340 */    71,   72,   73,   74,   75,   76,   77,   78,  194,   80,
 /*   350 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*   360 */    19,  165,   96,  150,  208,   99,  100,  101,  150,   19,
 /*   370 */   174,  226,  218,   58,  215,   60,  110,   27,  165,  150,
 /*   380 */   105,  106,  107,  165,   26,   27,  155,  174,  175,   48,
 /*   390 */    49,  116,  174,  175,  165,  183,   24,   22,   26,  245,
 /*   400 */   166,   26,   27,  174,  175,  136,  160,   66,   67,   68,
 /*   410 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*   420 */   160,   80,   81,   82,   83,   84,   85,   86,   87,   88,
 /*   430 */    89,   90,   19,  220,  150,  150,   23,  183,  220,   23,
 /*   440 */   194,   25,   84,   96,  160,  216,   99,  100,  101,  165,
 /*   450 */   165,  183,   94,   95,  194,  170,  150,  110,  174,  175,
 /*   460 */   229,   48,   49,  236,  158,  234,   94,  161,  162,   94,
 /*   470 */    95,  165,   86,   87,   88,   89,   90,  136,  194,   66,
 /*   480 */    67,   68,   69,   70,   71,   72,   73,   74,   75,   76,
 /*   490 */    77,   78,  150,   80,   81,   82,   83,   84,   85,   86,
 /*   500 */    87,   88,   89,   90,   19,  150,  160,  165,   23,   26,
 /*   510 */    27,   95,  153,  150,   26,   27,  231,  232,   22,   19,
 /*   520 */   165,   29,   26,   27,  222,   33,  224,  225,  165,  174,
 /*   530 */   175,  150,   31,   48,   49,  193,  120,  174,  175,   47,
 /*   540 */   194,   40,  161,  162,  242,  166,  165,  237,  166,  167,
 /*   550 */   168,   66,   67,   68,   69,   70,   71,   72,   73,   74,
 /*   560 */    75,   76,   77,   78,  218,   80,   81,   82,   83,   84,
 /*   570 */    85,   86,   87,   88,   89,   90,   19,   94,   95,   12,
 /*   580 */    23,  235,   94,   95,  205,  243,  240,  150,  196,  150,
 /*   590 */    94,   95,  150,  198,  150,   28,  150,   23,   98,  169,
 /*   600 */   170,  171,  165,  120,  165,   48,   49,  165,  120,  165,
 /*   610 */    43,  165,   45,  174,  175,    0,    1,    2,  174,  175,
 /*   620 */   174,  175,   55,   66,   67,   68,   69,   70,   71,   72,
 /*   630 */    73,   74,   75,   76,   77,   78,  150,   80,   81,   82,
 /*   640 */    83,   84,   85,   86,   87,   88,   89,   90,   19,  150,
 /*   650 */   213,  165,   23,   19,   22,  150,   97,  166,   26,  217,
 /*   660 */   174,  175,  232,   22,  165,   24,  150,   23,   84,   85,
 /*   670 */   165,   48,   49,  174,  175,  116,   49,   48,   49,  174,
 /*   680 */   175,  165,  233,   49,   21,  233,  112,  128,  114,  115,
 /*   690 */   174,  175,   69,   70,  160,   66,   67,   68,   69,   70,
 /*   700 */    71,   72,   73,   74,   75,   76,   77,   78,  150,   80,
 /*   710 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*   720 */    19,   98,  150,  165,   61,   24,   94,  150,  194,  150,
 /*   730 */   150,  104,  174,  175,  190,  191,   23,  165,  104,  135,
 /*   740 */   150,  137,  165,  109,  165,  165,  174,  175,  228,   48,
 /*   750 */    49,  174,  175,  174,  175,  165,  112,  209,  114,  115,
 /*   760 */   160,  190,  191,  100,  174,  175,  177,   66,   67,   68,
 /*   770 */    69,   70,   71,   72,   73,   74,   75,   76,   77,   78,
 /*   780 */   150,   80,   81,   82,   83,   84,   85,   86,   87,   88,
 /*   790 */    89,   90,   19,  150,  194,  165,  105,  106,  107,  150,
 /*   800 */   150,  138,  248,  249,  174,  175,  206,  207,  165,  144,
 /*   810 */   145,  150,   23,  197,  165,  165,  177,  174,  175,  150,
 /*   820 */   204,   48,   49,  174,  175,  112,  165,  114,  115,   22,
 /*   830 */    23,   23,   25,   25,  165,  174,  175,  187,  182,   66,
 /*   840 */    67,   68,   69,   70,   71,   72,   73,   74,   75,   76,
 /*   850 */    77,   78,  150,   80,   81,   82,   83,   84,   85,   86,
 /*   860 */    87,   88,   89,   90,   19,  150,  150,  165,  150,   25,
 /*   870 */   150,  150,   65,  150,  206,  207,  174,  175,  113,  199,
 /*   880 */   165,  165,  117,  165,  150,  165,  165,  150,  165,  174,
 /*   890 */   175,  150,  166,   48,   49,  174,  175,  174,  175,  165,
 /*   900 */   178,  112,  165,  114,  115,  187,  165,  187,  174,  175,
 /*   910 */   177,   66,   67,   68,   69,   70,   71,   72,   73,   74,
 /*   920 */    75,   76,   77,   78,  150,   80,   81,   82,   83,   84,
 /*   930 */    85,   86,   87,   88,   89,   90,   19,  150,  150,  165,
 /*   940 */    25,  150,   86,  150,    7,    8,    9,  103,  174,  175,
 /*   950 */   213,  166,  165,  165,  213,  150,  165,  177,  165,  129,
 /*   960 */   130,  174,  175,  246,  247,   48,   49,  174,  175,  113,
 /*   970 */   165,   22,   23,  117,   25,  187,  177,  166,  187,  174,
 /*   980 */   175,    7,    8,  199,   67,   68,   69,   70,   71,   72,
 /*   990 */    73,   74,   75,   76,   77,   78,  150,   80,   81,   82,
 /*  1000 */    83,   84,   85,   86,   87,   88,   89,   90,   19,  150,
 /*  1010 */   160,  165,   98,  150,   65,  150,  205,  105,  106,  107,
 /*  1020 */   174,  175,  209,  109,  165,   97,   98,  150,  165,  209,
 /*  1030 */   165,  150,   35,  174,  175,  150,    6,   48,   49,  174,
 /*  1040 */   175,  126,  165,   23,  194,   25,  165,   23,  149,   25,
 /*  1050 */   165,  174,  175,   56,  166,  174,  175,   68,   69,   70,
 /*  1060 */    71,   72,   73,   74,   75,   76,   77,   78,  218,   80,
 /*  1070 */    81,   82,   83,   84,   85,   86,   87,   88,   89,   90,
 /*  1080 */    19,   20,   16,   22,  150,  150,  150,   26,   27,  150,
 /*  1090 */   240,   13,  150,  205,  149,   19,   20,   36,   22,  165,
 /*  1100 */   165,  165,   26,   27,  165,  108,  150,  165,  174,  175,
 /*  1110 */   174,  175,   36,  150,  149,   54,  150,  150,  150,  150,
 /*  1120 */    23,  165,   25,  151,   58,   64,   60,  149,  165,  159,
 /*  1130 */    54,  165,  165,  165,  165,  193,  150,  174,  175,  151,
 /*  1140 */    64,  174,  175,  174,  175,   84,   85,   22,  150,  193,
 /*  1150 */   150,  165,  150,  150,   93,   94,   95,   25,  194,   98,
 /*  1160 */    84,   85,   86,  165,  160,  165,  126,  165,  165,   93,
 /*  1170 */    94,   95,  174,  175,   98,    5,   23,  116,   25,  193,
 /*  1180 */    10,   11,   12,   13,   14,  123,  150,   17,  124,  199,
 /*  1190 */   129,  130,  131,  132,  133,  134,  193,  150,  194,   74,
 /*  1200 */    30,  165,   32,  150,  138,  129,  130,  131,  132,  133,
 /*  1210 */   134,   41,  165,   19,   20,   23,   22,   25,  165,  150,
 /*  1220 */    26,   27,  150,   53,  150,   55,  200,  174,  175,   59,
 /*  1230 */    36,   22,   62,  201,  165,   26,   27,  165,  150,  165,
 /*  1240 */   193,  150,   23,   23,   25,   25,  174,  175,   54,  150,
 /*  1250 */   150,  150,  122,  165,  150,  150,  165,  150,   64,  150,
 /*  1260 */   202,  125,  174,  175,  165,  165,  165,  193,  150,  165,
 /*  1270 */   165,  203,  165,   64,  165,  105,  106,  107,   84,   85,
 /*  1280 */    23,  111,   25,  165,  193,  150,  116,   93,   94,   95,
 /*  1290 */   227,  150,   98,   84,   85,  150,  150,  193,  135,  150,
 /*  1300 */   165,  150,  150,   94,  150,  150,  165,   98,  118,  139,
 /*  1310 */   165,  165,   23,   23,  165,   25,  165,  165,  150,  165,
 /*  1320 */   165,  150,  150,  129,  130,  131,  132,  133,  134,  104,
 /*  1330 */   150,  150,  150,  165,  150,  150,  165,  165,  129,  130,
 /*  1340 */   131,  210,  121,  157,  157,  165,  165,  165,  211,  165,
 /*  1350 */   165,  211,  210,  210,   65,  211,  104,   46,  184,  176,
 /*  1360 */    22,  103,   90,  230,  176,  176,   18,  156,  230,  178,
 /*  1370 */   157,  176,  179,  176,  176,  176,   44,  238,  156,  179,
 /*  1380 */   184,  157,  156,  135,  157,  157,  239,  156,   66,  157,
 /*  1390 */   189,  189,   22,  157,  219,   18,  192,  192,  192,  192,
 /*  1400 */   157,  189,  199,   39,  157,  241,  241,  199,  157,   37,
 /*  1410 */   244,  250,    1,  164,  180,  180,  247,   15,   23,   22,
 /*  1420 */   118,  118,  118,  118,  118,   98,  113,   22,   22,  219,
 /*  1430 */    23,   23,   11,   23,   22,   34,  120,   23,   25,   23,
 /*  1440 */    25,   22,   25,   34,  118,   23,   23,   27,   50,   22,
 /*  1450 */    50,   22,   34,   23,   22,   22,   22,  102,  109,   19,
 /*  1460 */    24,   20,   38,  104,   25,  104,  138,   22,   42,    5,
 /*  1470 */     1,  108,  127,   74,   22,   50,  119,   74,    1,   16,
 /*  1480 */    20,  121,   51,  108,  119,   57,   51,   22,   16,  127,
 /*  1490 */    23,   15,  140,   22,  128,    3,  251,    4,  251,  251,
 /*  1500 */    63,
};
#define YY_SHIFT_USE_DFLT (-111)
#define YY_SHIFT_MAX 405
static const short yy_shift_ofst[] = {
 /*     0 */   187, 1061, 1170, 1061, 1194, 1194,   -2,   64,  -19, 1194,
 /*    10 */  1194, 1194, 1194, 1194,  275,  358,    1,  125, 1076, 1194,
 /*    20 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,
 /*    30 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,
 /*    40 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,
 /*    50 */  1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194, 1194,  -48,
 /*    60 */   206,    1,    1,  124,  584,  584, -110,   53,  197,  269,
 /*    70 */   341,  413,  485,  557,  629,  701,  773,  845,  773,  773,
 /*    80 */   773,  773,  773,  773,  773,  773,  773,  773,  773,  773,
 /*    90 */   773,  773,  773,  773,  773,  773,  917,  989,  989,  -67,
 /*   100 */   -67,   -1,   -1,   55,   25,  386,    1,    1,    1,    1,
 /*   110 */     1,  634,  663,    1,    1,    1,    1,    1,    1,    1,
 /*   120 */     1,    1,    1,    1,    1,    1,  226,  124,  -17, -111,
 /*   130 */  -111, -111, 1209,   81,  375,  483,  488,  496,   90,  567,
 /*   140 */   567,    1,    1,    1,    1,    1,    1,    1,    1,    1,
 /*   150 */     1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
 /*   160 */     1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
 /*   170 */     1,    1,    1,    1,  807,  949,  615,  372,  372,  372,
 /*   180 */   559,  113, -110, -110, -110, -111, -111, -111,  198,  198,
 /*   190 */   266,  347,  574,  644,  713,  192,  789,  416,  937,  856,
 /*   200 */   632,   52,  997,  997,  997,  211,  211,  492,  691,  211,
 /*   210 */   211,  211,  211,  641,  765,  -13,  124,  830,  830,  604,
 /*   220 */   501,  501,  350,  501,  627,  501,  124,  501,  124,  844,
 /*   230 */   915,  350,  350,  915, 1030, 1030, 1030, 1030, 1078, 1078,
 /*   240 */  1132, -110, 1040, 1062, 1064, 1130, 1136, 1163, 1190, 1190,
 /*   250 */  1225, 1221, 1225, 1221, 1225, 1221, 1252, 1252, 1311, 1252,
 /*   260 */  1258, 1252, 1338, 1272, 1272, 1311, 1252, 1252, 1252, 1338,
 /*   270 */  1348, 1190, 1348, 1190, 1348, 1190, 1190, 1332, 1248, 1348,
 /*   280 */  1190, 1322, 1322, 1370, 1040, 1190, 1377, 1377, 1377, 1377,
 /*   290 */  1040, 1322, 1370, 1190, 1364, 1364, 1190, 1190, 1372, -111,
 /*   300 */  -111, -111, -111, -111,  623, 1066,  912,  315,  500,  808,
 /*   310 */  1020,  914,  974,  928, 1024, 1097, 1153, 1192, 1219, 1220,
 /*   320 */  1257, 1125, 1290, 1289, 1411, 1402, 1395, 1397, 1302, 1303,
 /*   330 */  1304, 1305, 1306, 1327, 1313, 1405, 1407, 1408, 1406, 1421,
 /*   340 */  1412, 1410, 1413, 1414, 1416, 1415, 1401, 1417, 1409, 1415,
 /*   350 */  1316, 1419, 1418, 1420, 1326, 1422, 1423, 1424, 1398, 1427,
 /*   360 */  1400, 1429, 1430, 1432, 1433, 1425, 1434, 1355, 1349, 1440,
 /*   370 */  1441, 1436, 1359, 1426, 1428, 1431, 1439, 1435, 1328, 1361,
 /*   380 */  1445, 1464, 1469, 1363, 1399, 1403, 1345, 1452, 1357, 1477,
 /*   390 */  1463, 1360, 1460, 1365, 1375, 1362, 1465, 1366, 1467, 1472,
 /*   400 */  1437, 1476, 1352, 1471, 1492, 1493,
};
#define YY_REDUCE_USE_DFLT (-180)
#define YY_REDUCE_MAX 303
static const short yy_reduce_ofst[] = {
 /*     0 */  -141,   82,  154,  284,   12,   75,   69,   73,  -59,  145,
 /*    10 */   159,  229,  213,  218,  346,  285,  306,  302,  355,  363,
 /*    20 */   439,  444,  446,  486,  499,  505,  516,  558,  572,  577,
 /*    30 */   579,  590,  630,  643,  649,  661,  702,  715,  721,  723,
 /*    40 */   734,  774,  787,  793,  805,  846,  859,  865,  877,  881,
 /*    50 */   934,  936,  963,  967,  969,  998, 1053, 1072, 1088, -179,
 /*    60 */   850,  342,  381,   85,   89,  430,  600,    2,    2,    2,
 /*    70 */     2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
 /*    80 */     2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
 /*    90 */     2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
 /*   100 */     2,    2,    2,  121,    2,    2,  437,  650,  718,  720,
 /*   110 */   788,  -21,  231,  956,  737,  791,  -47,  741,  942,  986,
 /*   120 */  1003, 1047, 1074, 1091,  442, 1104,    2,  382,    2,    2,
 /*   130 */     2,    2,  196,  126,  580,  669,  716,  863,  885,  544,
 /*   140 */   571,  935,  939,  966,  968, 1000,  885, 1002, 1036, 1069,
 /*   150 */  1099, 1100, 1101, 1105, 1107, 1109, 1118, 1135, 1141, 1145,
 /*   160 */  1146, 1149, 1151, 1152, 1154, 1155, 1168, 1171, 1172, 1180,
 /*   170 */  1181, 1182, 1184, 1185,  554,  554,  665,  379,  811,  888,
 /*   180 */  -134,  246,  260,  534, 1004,  616,  668,  717,  -98,  -70,
 /*   190 */   -54,   36,   41,   41,   41,   48,   41,  156,  149,  136,
 /*   200 */   234,  156,  212,  254,  268,   41,   41,  227,  310,   41,
 /*   210 */    41,   41,   41,  359,  392,  395,  491,  449,  452,  520,
 /*   220 */   589,  639,  548,  733,  656,  780,  726,  799,  785,  722,
 /*   230 */   680,  813,  820,  784,  899,  945,  965,  978,  972,  988,
 /*   240 */   970,  964,  990, 1026, 1032, 1058, 1068, 1063, 1186, 1187,
 /*   250 */  1131, 1137, 1142, 1140, 1143, 1144, 1183, 1188, 1174, 1189,
 /*   260 */  1191, 1195, 1193, 1133, 1138, 1196, 1197, 1198, 1199, 1200,
 /*   270 */  1211, 1213, 1222, 1224, 1226, 1227, 1228, 1139, 1147, 1231,
 /*   280 */  1232, 1201, 1202, 1175, 1203, 1236, 1204, 1205, 1206, 1207,
 /*   290 */  1208, 1212, 1210, 1243, 1164, 1165, 1247, 1251, 1166, 1249,
 /*   300 */  1234, 1235, 1169, 1161,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   618,  853,  934,  934,  853,  934,  934,  880,  741,  851,
 /*    10 */   934,  934,  934,  934,  934,  880,  934,  909,  934,  934,
 /*    20 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*    30 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*    40 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*    50 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  825,
 /*    60 */   934,  934,  934,  657,  880,  880,  745,  776,  934,  934,
 /*    70 */   934,  934,  934,  934,  934,  934,  777,  934,  855,  850,
 /*    80 */   846,  848,  847,  854,  778,  767,  774,  781,  756,  893,
 /*    90 */   783,  784,  790,  791,  910,  908,  813,  812,  831,  815,
 /*   100 */   837,  814,  824,  649,  816,  817,  934,  934,  934,  934,
 /*   110 */   934,  710,  644,  934,  934,  934,  934,  934,  934,  934,
 /*   120 */   934,  934,  934,  934,  934,  934,  818,  934,  819,  832,
 /*   130 */   833,  834,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   140 */   934,  624,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   150 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   160 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  866,
 /*   170 */   934,  913,  915,  934,  934,  934,  618,  741,  741,  741,
 /*   180 */   934,  934,  934,  934,  934,  735,  745,  927,  934,  934,
 /*   190 */   701,  934,  934,  934,  934,  934,  934,  934,  626,  733,
 /*   200 */   659,  743,  934,  934,  934,  646,  722,  886,  934,  900,
 /*   210 */   898,  724,  786,  934,  733,  742,  934,  934,  934,  849,
 /*   220 */   770,  770,  758,  770,  680,  770,  934,  770,  934,  683,
 /*   230 */   780,  758,  758,  780,  623,  623,  623,  623,  634,  634,
 /*   240 */   700,  934,  780,  771,  773,  763,  775,  934,  749,  749,
 /*   250 */   757,  762,  757,  762,  757,  762,  712,  712,  697,  712,
 /*   260 */   683,  712,  859,  863,  863,  697,  712,  712,  712,  859,
 /*   270 */   641,  749,  641,  749,  641,  749,  749,  890,  892,  641,
 /*   280 */   749,  714,  714,  792,  780,  749,  721,  721,  721,  721,
 /*   290 */   780,  714,  792,  749,  912,  912,  749,  749,  920,  667,
 /*   300 */   685,  685,  927,  932,  934,  934,  934,  934,  934,  934,
 /*   310 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   320 */   934,  873,  934,  934,  934,  632,  934,  651,  799,  804,
 /*   330 */   800,  934,  801,  934,  727,  934,  934,  934,  934,  934,
 /*   340 */   934,  934,  934,  934,  934,  852,  934,  764,  934,  772,
 /*   350 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   360 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   370 */   934,  934,  934,  934,  934,  888,  889,  934,  934,  934,
 /*   380 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   390 */   934,  934,  934,  934,  934,  934,  934,  934,  934,  934,
 /*   400 */   919,  934,  934,  922,  619,  934,  614,  616,  617,  621,
 /*   410 */   622,  625,  651,  652,  654,  655,  656,  627,  628,  629,
 /*   420 */   630,  631,  633,  637,  635,  636,  638,  645,  647,  666,
 /*   430 */   668,  670,  731,  732,  796,  725,  726,  730,  653,  807,
 /*   440 */   798,  802,  803,  805,  806,  820,  821,  823,  829,  836,
 /*   450 */   839,  822,  827,  828,  830,  835,  838,  728,  729,  842,
 /*   460 */   660,  661,  664,  665,  876,  878,  877,  879,  663,  662,
 /*   470 */   808,  811,  844,  845,  901,  902,  903,  904,  905,  840,
 /*   480 */   750,  843,  826,  765,  768,  769,  766,  734,  744,  752,
 /*   490 */   753,  754,  755,  739,  740,  746,  761,  794,  795,  759,
 /*   500 */   760,  747,  748,  736,  737,  738,  841,  797,  809,  810,
 /*   510 */   671,  672,  804,  673,  674,  675,  713,  716,  717,  718,
 /*   520 */   676,  695,  698,  699,  677,  684,  678,  679,  686,  687,
 /*   530 */   688,  691,  692,  693,  694,  689,  690,  860,  861,  864,
 /*   540 */   862,  681,  682,  696,  669,  658,  650,  702,  705,  706,
 /*   550 */   707,  708,  709,  711,  703,  704,  648,  639,  642,  751,
 /*   560 */   882,  891,  887,  883,  884,  885,  643,  856,  857,  715,
 /*   570 */   788,  789,  881,  894,  896,  793,  897,  899,  895,  924,
 /*   580 */   640,  719,  720,  723,  865,  906,  779,  782,  785,  787,
 /*   590 */   867,  868,  869,  870,  871,  874,  875,  872,  907,  911,
 /*   600 */   914,  916,  917,  918,  921,  923,  928,  929,  930,  933,
 /*   610 */   931,  620,  615,
};
#define YY_SZ_ACTTAB (int)(sizeof(yy_action)/sizeof(yy_action[0]))

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
   26,  /*    EXPLAIN => ID */
   26,  /*      QUERY => ID */
   26,  /*       PLAN => ID */
   26,  /*      BEGIN => ID */
    0,  /* TRANSACTION => nothing */
   26,  /*   DEFERRED => ID */
   26,  /*  IMMEDIATE => ID */
   26,  /*  EXCLUSIVE => ID */
    0,  /*     COMMIT => nothing */
   26,  /*        END => ID */
   26,  /*   ROLLBACK => ID */
   26,  /*  SAVEPOINT => ID */
   26,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   26,  /*         IF => ID */
    0,  /*        NOT => nothing */
    0,  /*     EXISTS => nothing */
   26,  /*       TEMP => ID */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*         AS => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   26,  /*      ABORT => ID */
   26,  /*      AFTER => ID */
   26,  /*    ANALYZE => ID */
   26,  /*        ASC => ID */
   26,  /*     ATTACH => ID */
   26,  /*     BEFORE => ID */
   26,  /*         BY => ID */
   26,  /*    CASCADE => ID */
   26,  /*       CAST => ID */
   26,  /*   COLUMNKW => ID */
   26,  /*   CONFLICT => ID */
   26,  /*   DATABASE => ID */
   26,  /*       DESC => ID */
   26,  /*     DETACH => ID */
   26,  /*       EACH => ID */
   26,  /*       FAIL => ID */
   26,  /*        FOR => ID */
   26,  /*     IGNORE => ID */
   26,  /*  INITIALLY => ID */
   26,  /*    INSTEAD => ID */
   26,  /*    LIKE_KW => ID */
   26,  /*      MATCH => ID */
   26,  /*        KEY => ID */
   26,  /*         OF => ID */
   26,  /*     OFFSET => ID */
   26,  /*     PRAGMA => ID */
   26,  /*      RAISE => ID */
   26,  /*    REPLACE => ID */
   26,  /*   RESTRICT => ID */
   26,  /*        ROW => ID */
   26,  /*    TRIGGER => ID */
   26,  /*     VACUUM => ID */
   26,  /*       VIEW => ID */
   26,  /*    VIRTUAL => ID */
   26,  /*    REINDEX => ID */
   26,  /*     RENAME => ID */
   26,  /*   CTIME_KW => ID */
    0,  /*        ANY => nothing */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*         IS => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*     ISNULL => nothing */
    0,  /*    NOTNULL => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     UMINUS => nothing */
    0,  /*      UPLUS => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*     STRING => nothing */
    0,  /*    JOIN_KW => nothing */
    0,  /* CONSTRAINT => nothing */
    0,  /*    DEFAULT => nothing */
    0,  /*       NULL => nothing */
    0,  /*    PRIMARY => nothing */
    0,  /*     UNIQUE => nothing */
    0,  /*      CHECK => nothing */
    0,  /* REFERENCES => nothing */
    0,  /*   AUTOINCR => nothing */
    0,  /*         ON => nothing */
    0,  /*     DELETE => nothing */
    0,  /*     UPDATE => nothing */
    0,  /*     INSERT => nothing */
    0,  /*        SET => nothing */
    0,  /* DEFERRABLE => nothing */
    0,  /*    FOREIGN => nothing */
    0,  /*       DROP => nothing */
    0,  /*      UNION => nothing */
    0,  /*        ALL => nothing */
    0,  /*     EXCEPT => nothing */
    0,  /*  INTERSECT => nothing */
    0,  /*     SELECT => nothing */
    0,  /*   DISTINCT => nothing */
    0,  /*        DOT => nothing */
    0,  /*       FROM => nothing */
    0,  /*       JOIN => nothing */
    0,  /*      USING => nothing */
    0,  /*      ORDER => nothing */
    0,  /*      GROUP => nothing */
    0,  /*     HAVING => nothing */
    0,  /*      LIMIT => nothing */
    0,  /*      WHERE => nothing */
    0,  /*       INTO => nothing */
    0,  /*     VALUES => nothing */
    0,  /*    INTEGER => nothing */
    0,  /*      FLOAT => nothing */
    0,  /*       BLOB => nothing */
    0,  /*   REGISTER => nothing */
    0,  /*   VARIABLE => nothing */
    0,  /*       CASE => nothing */
    0,  /*       WHEN => nothing */
    0,  /*       THEN => nothing */
    0,  /*       ELSE => nothing */
    0,  /*      INDEX => nothing */
    0,  /*      ALTER => nothing */
    0,  /*        ADD => nothing */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyidxMax;                 /* Maximum value of yyidx */
#endif
  int yyerrcnt;                 /* Shifts left before out of the error */
  sqlite3ParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3ParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "BEGIN",         "TRANSACTION",   "DEFERRED",    
  "IMMEDIATE",     "EXCLUSIVE",     "COMMIT",        "END",         
  "ROLLBACK",      "SAVEPOINT",     "RELEASE",       "TO",          
  "TABLE",         "CREATE",        "IF",            "NOT",         
  "EXISTS",        "TEMP",          "LP",            "RP",          
  "AS",            "COMMA",         "ID",            "INDEXED",     
  "ABORT",         "AFTER",         "ANALYZE",       "ASC",         
  "ATTACH",        "BEFORE",        "BY",            "CASCADE",     
  "CAST",          "COLUMNKW",      "CONFLICT",      "DATABASE",    
  "DESC",          "DETACH",        "EACH",          "FAIL",        
  "FOR",           "IGNORE",        "INITIALLY",     "INSTEAD",     
  "LIKE_KW",       "MATCH",         "KEY",           "OF",          
  "OFFSET",        "PRAGMA",        "RAISE",         "REPLACE",     
  "RESTRICT",      "ROW",           "TRIGGER",       "VACUUM",      
  "VIEW",          "VIRTUAL",       "REINDEX",       "RENAME",      
  "CTIME_KW",      "ANY",           "OR",            "AND",         
  "IS",            "BETWEEN",       "IN",            "ISNULL",      
  "NOTNULL",       "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "UMINUS",      
  "UPLUS",         "BITNOT",        "STRING",        "JOIN_KW",     
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "DELETE",        "UPDATE",        "INSERT",      
  "SET",           "DEFERRABLE",    "FOREIGN",       "DROP",        
  "UNION",         "ALL",           "EXCEPT",        "INTERSECT",   
  "SELECT",        "DISTINCT",      "DOT",           "FROM",        
  "JOIN",          "USING",         "ORDER",         "GROUP",       
  "HAVING",        "LIMIT",         "WHERE",         "INTO",        
  "VALUES",        "INTEGER",       "FLOAT",         "BLOB",        
  "REGISTER",      "VARIABLE",      "CASE",          "WHEN",        
  "THEN",          "ELSE",          "INDEX",         "ALTER",       
  "ADD",           "error",         "input",         "cmdlist",     
  "ecmd",          "explain",       "cmdx",          "cmd",         
  "transtype",     "trans_opt",     "nm",            "savepoint_opt",
  "create_table",  "create_table_args",  "createkw",      "temp",        
  "ifnotexists",   "dbnm",          "columnlist",    "conslist_opt",
  "select",        "column",        "columnid",      "type",        
  "carglist",      "id",            "ids",           "typetoken",   
  "typename",      "signed",        "plus_num",      "minus_num",   
  "carg",          "ccons",         "term",          "expr",        
  "onconf",        "sortorder",     "autoinc",       "idxlist_opt", 
  "refargs",       "defer_subclause",  "refarg",        "refact",      
  "init_deferred_pred_opt",  "conslist",      "tcons",         "idxlist",     
  "defer_subclause_opt",  "orconf",        "resolvetype",   "raisetype",   
  "ifexists",      "fullname",      "oneselect",     "multiselect_op",
  "distinct",      "selcollist",    "from",          "where_opt",   
  "groupby_opt",   "having_opt",    "orderby_opt",   "limit_opt",   
  "sclp",          "as",            "seltablist",    "stl_prefix",  
  "joinop",        "indexed_opt",   "on_opt",        "using_opt",   
  "joinop2",       "inscollist",    "sortlist",      "sortitem",    
  "nexprlist",     "setlist",       "insert_cmd",    "inscollist_opt",
  "itemlist",      "exprlist",      "likeop",        "escape",      
  "between_op",    "in_op",         "case_operand",  "case_exprlist",
  "case_else",     "uniqueflag",    "collate",       "nmnum",       
  "plus_opt",      "number",        "trigger_decl",  "trigger_cmd_list",
  "trigger_time",  "trigger_event",  "foreach_clause",  "when_clause", 
  "trigger_cmd",   "database_kw_opt",  "key_opt",       "add_column_fullname",
  "kwcolumn_opt",  "create_vtab",   "vtabarglist",   "vtabarg",     
  "vtabargtoken",  "lp",            "anylist",     
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "input ::= cmdlist",
 /*   1 */ "cmdlist ::= cmdlist ecmd",
 /*   2 */ "cmdlist ::= ecmd",
 /*   3 */ "ecmd ::= SEMI",
 /*   4 */ "ecmd ::= explain cmdx SEMI",
 /*   5 */ "explain ::=",
 /*   6 */ "explain ::= EXPLAIN",
 /*   7 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   8 */ "cmdx ::= cmd",
 /*   9 */ "cmd ::= BEGIN transtype trans_opt",
 /*  10 */ "trans_opt ::=",
 /*  11 */ "trans_opt ::= TRANSACTION",
 /*  12 */ "trans_opt ::= TRANSACTION nm",
 /*  13 */ "transtype ::=",
 /*  14 */ "transtype ::= DEFERRED",
 /*  15 */ "transtype ::= IMMEDIATE",
 /*  16 */ "transtype ::= EXCLUSIVE",
 /*  17 */ "cmd ::= COMMIT trans_opt",
 /*  18 */ "cmd ::= END trans_opt",
 /*  19 */ "cmd ::= ROLLBACK trans_opt",
 /*  20 */ "savepoint_opt ::= SAVEPOINT",
 /*  21 */ "savepoint_opt ::=",
 /*  22 */ "cmd ::= SAVEPOINT nm",
 /*  23 */ "cmd ::= RELEASE savepoint_opt nm",
 /*  24 */ "cmd ::= ROLLBACK trans_opt TO savepoint_opt nm",
 /*  25 */ "cmd ::= create_table create_table_args",
 /*  26 */ "create_table ::= createkw temp TABLE ifnotexists nm dbnm",
 /*  27 */ "createkw ::= CREATE",
 /*  28 */ "ifnotexists ::=",
 /*  29 */ "ifnotexists ::= IF NOT EXISTS",
 /*  30 */ "temp ::= TEMP",
 /*  31 */ "temp ::=",
 /*  32 */ "create_table_args ::= LP columnlist conslist_opt RP",
 /*  33 */ "create_table_args ::= AS select",
 /*  34 */ "columnlist ::= columnlist COMMA column",
 /*  35 */ "columnlist ::= column",
 /*  36 */ "column ::= columnid type carglist",
 /*  37 */ "columnid ::= nm",
 /*  38 */ "id ::= ID",
 /*  39 */ "id ::= INDEXED",
 /*  40 */ "ids ::= ID|STRING",
 /*  41 */ "nm ::= id",
 /*  42 */ "nm ::= STRING",
 /*  43 */ "nm ::= JOIN_KW",
 /*  44 */ "type ::=",
 /*  45 */ "type ::= typetoken",
 /*  46 */ "typetoken ::= typename",
 /*  47 */ "typetoken ::= typename LP signed RP",
 /*  48 */ "typetoken ::= typename LP signed COMMA signed RP",
 /*  49 */ "typename ::= ids",
 /*  50 */ "typename ::= typename ids",
 /*  51 */ "signed ::= plus_num",
 /*  52 */ "signed ::= minus_num",
 /*  53 */ "carglist ::= carglist carg",
 /*  54 */ "carglist ::=",
 /*  55 */ "carg ::= CONSTRAINT nm ccons",
 /*  56 */ "carg ::= ccons",
 /*  57 */ "ccons ::= DEFAULT term",
 /*  58 */ "ccons ::= DEFAULT LP expr RP",
 /*  59 */ "ccons ::= DEFAULT PLUS term",
 /*  60 */ "ccons ::= DEFAULT MINUS term",
 /*  61 */ "ccons ::= DEFAULT id",
 /*  62 */ "ccons ::= NULL onconf",
 /*  63 */ "ccons ::= NOT NULL onconf",
 /*  64 */ "ccons ::= PRIMARY KEY sortorder onconf autoinc",
 /*  65 */ "ccons ::= UNIQUE onconf",
 /*  66 */ "ccons ::= CHECK LP expr RP",
 /*  67 */ "ccons ::= REFERENCES nm idxlist_opt refargs",
 /*  68 */ "ccons ::= defer_subclause",
 /*  69 */ "ccons ::= COLLATE ids",
 /*  70 */ "autoinc ::=",
 /*  71 */ "autoinc ::= AUTOINCR",
 /*  72 */ "refargs ::=",
 /*  73 */ "refargs ::= refargs refarg",
 /*  74 */ "refarg ::= MATCH nm",
 /*  75 */ "refarg ::= ON DELETE refact",
 /*  76 */ "refarg ::= ON UPDATE refact",
 /*  77 */ "refarg ::= ON INSERT refact",
 /*  78 */ "refact ::= SET NULL",
 /*  79 */ "refact ::= SET DEFAULT",
 /*  80 */ "refact ::= CASCADE",
 /*  81 */ "refact ::= RESTRICT",
 /*  82 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  83 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  84 */ "init_deferred_pred_opt ::=",
 /*  85 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  86 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  87 */ "conslist_opt ::=",
 /*  88 */ "conslist_opt ::= COMMA conslist",
 /*  89 */ "conslist ::= conslist COMMA tcons",
 /*  90 */ "conslist ::= conslist tcons",
 /*  91 */ "conslist ::= tcons",
 /*  92 */ "tcons ::= CONSTRAINT nm",
 /*  93 */ "tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf",
 /*  94 */ "tcons ::= UNIQUE LP idxlist RP onconf",
 /*  95 */ "tcons ::= CHECK LP expr RP onconf",
 /*  96 */ "tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt",
 /*  97 */ "defer_subclause_opt ::=",
 /*  98 */ "defer_subclause_opt ::= defer_subclause",
 /*  99 */ "onconf ::=",
 /* 100 */ "onconf ::= ON CONFLICT resolvetype",
 /* 101 */ "orconf ::=",
 /* 102 */ "orconf ::= OR resolvetype",
 /* 103 */ "resolvetype ::= raisetype",
 /* 104 */ "resolvetype ::= IGNORE",
 /* 105 */ "resolvetype ::= REPLACE",
 /* 106 */ "cmd ::= DROP TABLE ifexists fullname",
 /* 107 */ "ifexists ::= IF EXISTS",
 /* 108 */ "ifexists ::=",
 /* 109 */ "cmd ::= createkw temp VIEW ifnotexists nm dbnm AS select",
 /* 110 */ "cmd ::= DROP VIEW ifexists fullname",
 /* 111 */ "cmd ::= select",
 /* 112 */ "select ::= oneselect",
 /* 113 */ "select ::= select multiselect_op oneselect",
 /* 114 */ "multiselect_op ::= UNION",
 /* 115 */ "multiselect_op ::= UNION ALL",
 /* 116 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /* 117 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /* 118 */ "distinct ::= DISTINCT",
 /* 119 */ "distinct ::= ALL",
 /* 120 */ "distinct ::=",
 /* 121 */ "sclp ::= selcollist COMMA",
 /* 122 */ "sclp ::=",
 /* 123 */ "selcollist ::= sclp expr as",
 /* 124 */ "selcollist ::= sclp STAR",
 /* 125 */ "selcollist ::= sclp nm DOT STAR",
 /* 126 */ "as ::= AS nm",
 /* 127 */ "as ::= ids",
 /* 128 */ "as ::=",
 /* 129 */ "from ::=",
 /* 130 */ "from ::= FROM seltablist",
 /* 131 */ "stl_prefix ::= seltablist joinop",
 /* 132 */ "stl_prefix ::=",
 /* 133 */ "seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt",
 /* 134 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /* 135 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /* 136 */ "dbnm ::=",
 /* 137 */ "dbnm ::= DOT nm",
 /* 138 */ "fullname ::= nm dbnm",
 /* 139 */ "joinop ::= COMMA|JOIN",
 /* 140 */ "joinop ::= JOIN_KW JOIN",
 /* 141 */ "joinop ::= JOIN_KW nm JOIN",
 /* 142 */ "joinop ::= JOIN_KW nm nm JOIN",
 /* 143 */ "on_opt ::= ON expr",
 /* 144 */ "on_opt ::=",
 /* 145 */ "indexed_opt ::=",
 /* 146 */ "indexed_opt ::= INDEXED BY nm",
 /* 147 */ "indexed_opt ::= NOT INDEXED",
 /* 148 */ "using_opt ::= USING LP inscollist RP",
 /* 149 */ "using_opt ::=",
 /* 150 */ "orderby_opt ::=",
 /* 151 */ "orderby_opt ::= ORDER BY sortlist",
 /* 152 */ "sortlist ::= sortlist COMMA sortitem sortorder",
 /* 153 */ "sortlist ::= sortitem sortorder",
 /* 154 */ "sortitem ::= expr",
 /* 155 */ "sortorder ::= ASC",
 /* 156 */ "sortorder ::= DESC",
 /* 157 */ "sortorder ::=",
 /* 158 */ "groupby_opt ::=",
 /* 159 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 160 */ "having_opt ::=",
 /* 161 */ "having_opt ::= HAVING expr",
 /* 162 */ "limit_opt ::=",
 /* 163 */ "limit_opt ::= LIMIT expr",
 /* 164 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 165 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 166 */ "cmd ::= DELETE FROM fullname indexed_opt where_opt",
 /* 167 */ "where_opt ::=",
 /* 168 */ "where_opt ::= WHERE expr",
 /* 169 */ "cmd ::= UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 170 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 171 */ "setlist ::= nm EQ expr",
 /* 172 */ "cmd ::= insert_cmd INTO fullname inscollist_opt VALUES LP itemlist RP",
 /* 173 */ "cmd ::= insert_cmd INTO fullname inscollist_opt select",
 /* 174 */ "cmd ::= insert_cmd INTO fullname inscollist_opt DEFAULT VALUES",
 /* 175 */ "insert_cmd ::= INSERT orconf",
 /* 176 */ "insert_cmd ::= REPLACE",
 /* 177 */ "itemlist ::= itemlist COMMA expr",
 /* 178 */ "itemlist ::= expr",
 /* 179 */ "inscollist_opt ::=",
 /* 180 */ "inscollist_opt ::= LP inscollist RP",
 /* 181 */ "inscollist ::= inscollist COMMA nm",
 /* 182 */ "inscollist ::= nm",
 /* 183 */ "expr ::= term",
 /* 184 */ "expr ::= LP expr RP",
 /* 185 */ "term ::= NULL",
 /* 186 */ "expr ::= id",
 /* 187 */ "expr ::= JOIN_KW",
 /* 188 */ "expr ::= nm DOT nm",
 /* 189 */ "expr ::= nm DOT nm DOT nm",
 /* 190 */ "term ::= INTEGER|FLOAT|BLOB",
 /* 191 */ "term ::= STRING",
 /* 192 */ "expr ::= REGISTER",
 /* 193 */ "expr ::= VARIABLE",
 /* 194 */ "expr ::= expr COLLATE ids",
 /* 195 */ "expr ::= CAST LP expr AS typetoken RP",
 /* 196 */ "expr ::= ID LP distinct exprlist RP",
 /* 197 */ "expr ::= ID LP STAR RP",
 /* 198 */ "term ::= CTIME_KW",
 /* 199 */ "expr ::= expr AND expr",
 /* 200 */ "expr ::= expr OR expr",
 /* 201 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 202 */ "expr ::= expr EQ|NE expr",
 /* 203 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 204 */ "expr ::= expr PLUS|MINUS expr",
 /* 205 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 206 */ "expr ::= expr CONCAT expr",
 /* 207 */ "likeop ::= LIKE_KW",
 /* 208 */ "likeop ::= NOT LIKE_KW",
 /* 209 */ "likeop ::= MATCH",
 /* 210 */ "likeop ::= NOT MATCH",
 /* 211 */ "escape ::= ESCAPE expr",
 /* 212 */ "escape ::=",
 /* 213 */ "expr ::= expr likeop expr escape",
 /* 214 */ "expr ::= expr ISNULL|NOTNULL",
 /* 215 */ "expr ::= expr IS NULL",
 /* 216 */ "expr ::= expr NOT NULL",
 /* 217 */ "expr ::= expr IS NOT NULL",
 /* 218 */ "expr ::= NOT expr",
 /* 219 */ "expr ::= BITNOT expr",
 /* 220 */ "expr ::= MINUS expr",
 /* 221 */ "expr ::= PLUS expr",
 /* 222 */ "between_op ::= BETWEEN",
 /* 223 */ "between_op ::= NOT BETWEEN",
 /* 224 */ "expr ::= expr between_op expr AND expr",
 /* 225 */ "in_op ::= IN",
 /* 226 */ "in_op ::= NOT IN",
 /* 227 */ "expr ::= expr in_op LP exprlist RP",
 /* 228 */ "expr ::= LP select RP",
 /* 229 */ "expr ::= expr in_op LP select RP",
 /* 230 */ "expr ::= expr in_op nm dbnm",
 /* 231 */ "expr ::= EXISTS LP select RP",
 /* 232 */ "expr ::= CASE case_operand case_exprlist case_else END",
 /* 233 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 234 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 235 */ "case_else ::= ELSE expr",
 /* 236 */ "case_else ::=",
 /* 237 */ "case_operand ::= expr",
 /* 238 */ "case_operand ::=",
 /* 239 */ "exprlist ::= nexprlist",
 /* 240 */ "exprlist ::=",
 /* 241 */ "nexprlist ::= nexprlist COMMA expr",
 /* 242 */ "nexprlist ::= expr",
 /* 243 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm dbnm ON nm LP idxlist RP",
 /* 244 */ "uniqueflag ::= UNIQUE",
 /* 245 */ "uniqueflag ::=",
 /* 246 */ "idxlist_opt ::=",
 /* 247 */ "idxlist_opt ::= LP idxlist RP",
 /* 248 */ "idxlist ::= idxlist COMMA nm collate sortorder",
 /* 249 */ "idxlist ::= nm collate sortorder",
 /* 250 */ "collate ::=",
 /* 251 */ "collate ::= COLLATE ids",
 /* 252 */ "cmd ::= DROP INDEX ifexists fullname",
 /* 253 */ "cmd ::= VACUUM",
 /* 254 */ "cmd ::= VACUUM nm",
 /* 255 */ "cmd ::= PRAGMA nm dbnm EQ nmnum",
 /* 256 */ "cmd ::= PRAGMA nm dbnm EQ ON",
 /* 257 */ "cmd ::= PRAGMA nm dbnm EQ DELETE",
 /* 258 */ "cmd ::= PRAGMA nm dbnm EQ minus_num",
 /* 259 */ "cmd ::= PRAGMA nm dbnm LP nmnum RP",
 /* 260 */ "cmd ::= PRAGMA nm dbnm",
 /* 261 */ "nmnum ::= plus_num",
 /* 262 */ "nmnum ::= nm",
 /* 263 */ "plus_num ::= plus_opt number",
 /* 264 */ "minus_num ::= MINUS number",
 /* 265 */ "number ::= INTEGER|FLOAT",
 /* 266 */ "plus_opt ::= PLUS",
 /* 267 */ "plus_opt ::=",
 /* 268 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 269 */ "trigger_decl ::= temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 270 */ "trigger_time ::= BEFORE",
 /* 271 */ "trigger_time ::= AFTER",
 /* 272 */ "trigger_time ::= INSTEAD OF",
 /* 273 */ "trigger_time ::=",
 /* 274 */ "trigger_event ::= DELETE|INSERT",
 /* 275 */ "trigger_event ::= UPDATE",
 /* 276 */ "trigger_event ::= UPDATE OF inscollist",
 /* 277 */ "foreach_clause ::=",
 /* 278 */ "foreach_clause ::= FOR EACH ROW",
 /* 279 */ "when_clause ::=",
 /* 280 */ "when_clause ::= WHEN expr",
 /* 281 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 282 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 283 */ "trigger_cmd ::= UPDATE orconf nm SET setlist where_opt",
 /* 284 */ "trigger_cmd ::= insert_cmd INTO nm inscollist_opt VALUES LP itemlist RP",
 /* 285 */ "trigger_cmd ::= insert_cmd INTO nm inscollist_opt select",
 /* 286 */ "trigger_cmd ::= DELETE FROM nm where_opt",
 /* 287 */ "trigger_cmd ::= select",
 /* 288 */ "expr ::= RAISE LP IGNORE RP",
 /* 289 */ "expr ::= RAISE LP raisetype COMMA nm RP",
 /* 290 */ "raisetype ::= ROLLBACK",
 /* 291 */ "raisetype ::= ABORT",
 /* 292 */ "raisetype ::= FAIL",
 /* 293 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 294 */ "cmd ::= ATTACH database_kw_opt expr AS expr key_opt",
 /* 295 */ "cmd ::= DETACH database_kw_opt expr",
 /* 296 */ "key_opt ::=",
 /* 297 */ "key_opt ::= KEY expr",
 /* 298 */ "database_kw_opt ::= DATABASE",
 /* 299 */ "database_kw_opt ::=",
 /* 300 */ "cmd ::= REINDEX",
 /* 301 */ "cmd ::= REINDEX nm dbnm",
 /* 302 */ "cmd ::= ANALYZE",
 /* 303 */ "cmd ::= ANALYZE nm dbnm",
 /* 304 */ "cmd ::= ALTER TABLE fullname RENAME TO nm",
 /* 305 */ "cmd ::= ALTER TABLE add_column_fullname ADD kwcolumn_opt column",
 /* 306 */ "add_column_fullname ::= fullname",
 /* 307 */ "kwcolumn_opt ::=",
 /* 308 */ "kwcolumn_opt ::= COLUMNKW",
 /* 309 */ "cmd ::= create_vtab",
 /* 310 */ "cmd ::= create_vtab LP vtabarglist RP",
 /* 311 */ "create_vtab ::= createkw VIRTUAL TABLE nm dbnm USING nm",
 /* 312 */ "vtabarglist ::= vtabarg",
 /* 313 */ "vtabarglist ::= vtabarglist COMMA vtabarg",
 /* 314 */ "vtabarg ::=",
 /* 315 */ "vtabarg ::= vtabarg vtabargtoken",
 /* 316 */ "vtabargtoken ::= ANY",
 /* 317 */ "vtabargtoken ::= lp anylist RP",
 /* 318 */ "lp ::= LP",
 /* 319 */ "anylist ::=",
 /* 320 */ "anylist ::= anylist ANY",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlite3Parser and sqlite3ParserFree.
*/
void *sqlite3ParserAlloc(void *(*mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyidxMax = 0;
#endif
#if YYSTACKDEPTH<=0
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlite3ParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
    case 160: /* select */
    case 194: /* oneselect */
{
#line 389 "parse.y"
sqlite3SelectDelete(pParse->db, (yypminor->yy243));
#line 1339 "parse.c"
}
      break;
    case 174: /* term */
    case 175: /* expr */
    case 199: /* where_opt */
    case 201: /* having_opt */
    case 210: /* on_opt */
    case 215: /* sortitem */
    case 223: /* escape */
    case 226: /* case_operand */
    case 228: /* case_else */
    case 239: /* when_clause */
    case 242: /* key_opt */
{
#line 700 "parse.y"
sqlite3ExprDelete(pParse->db, (yypminor->yy72));
#line 1356 "parse.c"
}
      break;
    case 179: /* idxlist_opt */
    case 187: /* idxlist */
    case 197: /* selcollist */
    case 200: /* groupby_opt */
    case 202: /* orderby_opt */
    case 204: /* sclp */
    case 214: /* sortlist */
    case 216: /* nexprlist */
    case 217: /* setlist */
    case 220: /* itemlist */
    case 221: /* exprlist */
    case 227: /* case_exprlist */
{
#line 962 "parse.y"
sqlite3ExprListDelete(pParse->db, (yypminor->yy148));
#line 1374 "parse.c"
}
      break;
    case 193: /* fullname */
    case 198: /* from */
    case 206: /* seltablist */
    case 207: /* stl_prefix */
{
#line 518 "parse.y"
sqlite3SrcListDelete(pParse->db, (yypminor->yy185));
#line 1384 "parse.c"
}
      break;
    case 211: /* using_opt */
    case 213: /* inscollist */
    case 219: /* inscollist_opt */
{
#line 550 "parse.y"
sqlite3IdListDelete(pParse->db, (yypminor->yy254));
#line 1393 "parse.c"
}
      break;
    case 235: /* trigger_cmd_list */
    case 240: /* trigger_cmd */
{
#line 1066 "parse.y"
sqlite3DeleteTriggerStep(pParse->db, (yypminor->yy145));
#line 1401 "parse.c"
}
      break;
    case 237: /* trigger_event */
{
#line 1052 "parse.y"
sqlite3IdListDelete(pParse->db, (yypminor->yy332).b);
#line 1408 "parse.c"
}
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor(pParser, yymajor, &yytos->minor);
  pParser->yyidx--;
  return yymajor;
}

/* 
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from sqlite3ParserAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void sqlite3ParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlite3ParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyidxMax;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
 
  if( stateno>YY_SHIFT_MAX || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_SZ_ACTTAB || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( j>=0 && j<YY_SZ_ACTTAB && yy_lookahead[j]==YYWILDCARD ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_MAX ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_MAX );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_SZ_ACTTAB || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_SZ_ACTTAB );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   sqlite3ParserARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
#line 40 "parse.y"

  UNUSED_PARAMETER(yypMinor); /* Silence some compiler warnings */
  sqlite3ErrorMsg(pParse, "parser stack overflow");
  pParse->parseError = 1;
#line 1586 "parse.c"
   sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer to the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( yypParser->yyidx>yypParser->yyidxMax ){
    yypParser->yyidxMax = yypParser->yyidx;
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," %s",yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 142, 1 },
  { 143, 2 },
  { 143, 1 },
  { 144, 1 },
  { 144, 3 },
  { 145, 0 },
  { 145, 1 },
  { 145, 3 },
  { 146, 1 },
  { 147, 3 },
  { 149, 0 },
  { 149, 1 },
  { 149, 2 },
  { 148, 0 },
  { 148, 1 },
  { 148, 1 },
  { 148, 1 },
  { 147, 2 },
  { 147, 2 },
  { 147, 2 },
  { 151, 1 },
  { 151, 0 },
  { 147, 2 },
  { 147, 3 },
  { 147, 5 },
  { 147, 2 },
  { 152, 6 },
  { 154, 1 },
  { 156, 0 },
  { 156, 3 },
  { 155, 1 },
  { 155, 0 },
  { 153, 4 },
  { 153, 2 },
  { 158, 3 },
  { 158, 1 },
  { 161, 3 },
  { 162, 1 },
  { 165, 1 },
  { 165, 1 },
  { 166, 1 },
  { 150, 1 },
  { 150, 1 },
  { 150, 1 },
  { 163, 0 },
  { 163, 1 },
  { 167, 1 },
  { 167, 4 },
  { 167, 6 },
  { 168, 1 },
  { 168, 2 },
  { 169, 1 },
  { 169, 1 },
  { 164, 2 },
  { 164, 0 },
  { 172, 3 },
  { 172, 1 },
  { 173, 2 },
  { 173, 4 },
  { 173, 3 },
  { 173, 3 },
  { 173, 2 },
  { 173, 2 },
  { 173, 3 },
  { 173, 5 },
  { 173, 2 },
  { 173, 4 },
  { 173, 4 },
  { 173, 1 },
  { 173, 2 },
  { 178, 0 },
  { 178, 1 },
  { 180, 0 },
  { 180, 2 },
  { 182, 2 },
  { 182, 3 },
  { 182, 3 },
  { 182, 3 },
  { 183, 2 },
  { 183, 2 },
  { 183, 1 },
  { 183, 1 },
  { 181, 3 },
  { 181, 2 },
  { 184, 0 },
  { 184, 2 },
  { 184, 2 },
  { 159, 0 },
  { 159, 2 },
  { 185, 3 },
  { 185, 2 },
  { 185, 1 },
  { 186, 2 },
  { 186, 7 },
  { 186, 5 },
  { 186, 5 },
  { 186, 10 },
  { 188, 0 },
  { 188, 1 },
  { 176, 0 },
  { 176, 3 },
  { 189, 0 },
  { 189, 2 },
  { 190, 1 },
  { 190, 1 },
  { 190, 1 },
  { 147, 4 },
  { 192, 2 },
  { 192, 0 },
  { 147, 8 },
  { 147, 4 },
  { 147, 1 },
  { 160, 1 },
  { 160, 3 },
  { 195, 1 },
  { 195, 2 },
  { 195, 1 },
  { 194, 9 },
  { 196, 1 },
  { 196, 1 },
  { 196, 0 },
  { 204, 2 },
  { 204, 0 },
  { 197, 3 },
  { 197, 2 },
  { 197, 4 },
  { 205, 2 },
  { 205, 1 },
  { 205, 0 },
  { 198, 0 },
  { 198, 2 },
  { 207, 2 },
  { 207, 0 },
  { 206, 7 },
  { 206, 7 },
  { 206, 7 },
  { 157, 0 },
  { 157, 2 },
  { 193, 2 },
  { 208, 1 },
  { 208, 2 },
  { 208, 3 },
  { 208, 4 },
  { 210, 2 },
  { 210, 0 },
  { 209, 0 },
  { 209, 3 },
  { 209, 2 },
  { 211, 4 },
  { 211, 0 },
  { 202, 0 },
  { 202, 3 },
  { 214, 4 },
  { 214, 2 },
  { 215, 1 },
  { 177, 1 },
  { 177, 1 },
  { 177, 0 },
  { 200, 0 },
  { 200, 3 },
  { 201, 0 },
  { 201, 2 },
  { 203, 0 },
  { 203, 2 },
  { 203, 4 },
  { 203, 4 },
  { 147, 5 },
  { 199, 0 },
  { 199, 2 },
  { 147, 7 },
  { 217, 5 },
  { 217, 3 },
  { 147, 8 },
  { 147, 5 },
  { 147, 6 },
  { 218, 2 },
  { 218, 1 },
  { 220, 3 },
  { 220, 1 },
  { 219, 0 },
  { 219, 3 },
  { 213, 3 },
  { 213, 1 },
  { 175, 1 },
  { 175, 3 },
  { 174, 1 },
  { 175, 1 },
  { 175, 1 },
  { 175, 3 },
  { 175, 5 },
  { 174, 1 },
  { 174, 1 },
  { 175, 1 },
  { 175, 1 },
  { 175, 3 },
  { 175, 6 },
  { 175, 5 },
  { 175, 4 },
  { 174, 1 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 175, 3 },
  { 222, 1 },
  { 222, 2 },
  { 222, 1 },
  { 222, 2 },
  { 223, 2 },
  { 223, 0 },
  { 175, 4 },
  { 175, 2 },
  { 175, 3 },
  { 175, 3 },
  { 175, 4 },
  { 175, 2 },
  { 175, 2 },
  { 175, 2 },
  { 175, 2 },
  { 224, 1 },
  { 224, 2 },
  { 175, 5 },
  { 225, 1 },
  { 225, 2 },
  { 175, 5 },
  { 175, 3 },
  { 175, 5 },
  { 175, 4 },
  { 175, 4 },
  { 175, 5 },
  { 227, 5 },
  { 227, 4 },
  { 228, 2 },
  { 228, 0 },
  { 226, 1 },
  { 226, 0 },
  { 221, 1 },
  { 221, 0 },
  { 216, 3 },
  { 216, 1 },
  { 147, 11 },
  { 229, 1 },
  { 229, 0 },
  { 179, 0 },
  { 179, 3 },
  { 187, 5 },
  { 187, 3 },
  { 230, 0 },
  { 230, 2 },
  { 147, 4 },
  { 147, 1 },
  { 147, 2 },
  { 147, 5 },
  { 147, 5 },
  { 147, 5 },
  { 147, 5 },
  { 147, 6 },
  { 147, 3 },
  { 231, 1 },
  { 231, 1 },
  { 170, 2 },
  { 171, 2 },
  { 233, 1 },
  { 232, 1 },
  { 232, 0 },
  { 147, 5 },
  { 234, 11 },
  { 236, 1 },
  { 236, 1 },
  { 236, 2 },
  { 236, 0 },
  { 237, 1 },
  { 237, 1 },
  { 237, 3 },
  { 238, 0 },
  { 238, 3 },
  { 239, 0 },
  { 239, 2 },
  { 235, 3 },
  { 235, 2 },
  { 240, 6 },
  { 240, 8 },
  { 240, 5 },
  { 240, 4 },
  { 240, 1 },
  { 175, 4 },
  { 175, 6 },
  { 191, 1 },
  { 191, 1 },
  { 191, 1 },
  { 147, 4 },
  { 147, 6 },
  { 147, 3 },
  { 242, 0 },
  { 242, 2 },
  { 241, 1 },
  { 241, 0 },
  { 147, 1 },
  { 147, 3 },
  { 147, 1 },
  { 147, 3 },
  { 147, 6 },
  { 147, 6 },
  { 243, 1 },
  { 244, 0 },
  { 244, 1 },
  { 147, 1 },
  { 147, 4 },
  { 245, 7 },
  { 246, 1 },
  { 246, 3 },
  { 247, 0 },
  { 247, 2 },
  { 248, 1 },
  { 248, 3 },
  { 249, 1 },
  { 250, 0 },
  { 250, 2 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlite3ParserARG_FETCH;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0 
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.  
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  /*memset(&yygotominor, 0, sizeof(yygotominor));*/
  yygotominor = yyzerominor;


  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 0: /* input ::= cmdlist */
      case 1: /* cmdlist ::= cmdlist ecmd */
      case 2: /* cmdlist ::= ecmd */
      case 3: /* ecmd ::= SEMI */
      case 4: /* ecmd ::= explain cmdx SEMI */
      case 10: /* trans_opt ::= */
      case 11: /* trans_opt ::= TRANSACTION */
      case 12: /* trans_opt ::= TRANSACTION nm */
      case 20: /* savepoint_opt ::= SAVEPOINT */
      case 21: /* savepoint_opt ::= */
      case 25: /* cmd ::= create_table create_table_args */
      case 34: /* columnlist ::= columnlist COMMA column */
      case 35: /* columnlist ::= column */
      case 44: /* type ::= */
      case 51: /* signed ::= plus_num */
      case 52: /* signed ::= minus_num */
      case 53: /* carglist ::= carglist carg */
      case 54: /* carglist ::= */
      case 55: /* carg ::= CONSTRAINT nm ccons */
      case 56: /* carg ::= ccons */
      case 62: /* ccons ::= NULL onconf */
      case 89: /* conslist ::= conslist COMMA tcons */
      case 90: /* conslist ::= conslist tcons */
      case 91: /* conslist ::= tcons */
      case 92: /* tcons ::= CONSTRAINT nm */
      case 266: /* plus_opt ::= PLUS */
      case 267: /* plus_opt ::= */
      case 277: /* foreach_clause ::= */
      case 278: /* foreach_clause ::= FOR EACH ROW */
      case 298: /* database_kw_opt ::= DATABASE */
      case 299: /* database_kw_opt ::= */
      case 307: /* kwcolumn_opt ::= */
      case 308: /* kwcolumn_opt ::= COLUMNKW */
      case 312: /* vtabarglist ::= vtabarg */
      case 313: /* vtabarglist ::= vtabarglist COMMA vtabarg */
      case 315: /* vtabarg ::= vtabarg vtabargtoken */
      case 319: /* anylist ::= */
#line 93 "parse.y"
{
}
#line 2058 "parse.c"
        break;
      case 5: /* explain ::= */
#line 98 "parse.y"
{ sqlite3BeginParse(pParse, 0); }
#line 2063 "parse.c"
        break;
      case 6: /* explain ::= EXPLAIN */
#line 100 "parse.y"
{ sqlite3BeginParse(pParse, 1); }
#line 2068 "parse.c"
        break;
      case 7: /* explain ::= EXPLAIN QUERY PLAN */
#line 101 "parse.y"
{ sqlite3BeginParse(pParse, 2); }
#line 2073 "parse.c"
        break;
      case 8: /* cmdx ::= cmd */
#line 103 "parse.y"
{ sqlite3FinishCoding(pParse); }
#line 2078 "parse.c"
        break;
      case 9: /* cmd ::= BEGIN transtype trans_opt */
#line 108 "parse.y"
{sqlite3BeginTransaction(pParse, yymsp[-1].minor.yy194);}
#line 2083 "parse.c"
        break;
      case 13: /* transtype ::= */
#line 113 "parse.y"
{yygotominor.yy194 = TK_DEFERRED;}
#line 2088 "parse.c"
        break;
      case 14: /* transtype ::= DEFERRED */
      case 15: /* transtype ::= IMMEDIATE */
      case 16: /* transtype ::= EXCLUSIVE */
      case 114: /* multiselect_op ::= UNION */
      case 116: /* multiselect_op ::= EXCEPT|INTERSECT */
#line 114 "parse.y"
{yygotominor.yy194 = yymsp[0].major;}
#line 2097 "parse.c"
        break;
      case 17: /* cmd ::= COMMIT trans_opt */
      case 18: /* cmd ::= END trans_opt */
#line 117 "parse.y"
{sqlite3CommitTransaction(pParse);}
#line 2103 "parse.c"
        break;
      case 19: /* cmd ::= ROLLBACK trans_opt */
#line 119 "parse.y"
{sqlite3RollbackTransaction(pParse);}
#line 2108 "parse.c"
        break;
      case 22: /* cmd ::= SAVEPOINT nm */
#line 123 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2115 "parse.c"
        break;
      case 23: /* cmd ::= RELEASE savepoint_opt nm */
#line 126 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2122 "parse.c"
        break;
      case 24: /* cmd ::= ROLLBACK trans_opt TO savepoint_opt nm */
#line 129 "parse.y"
{
  sqlite3Savepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2129 "parse.c"
        break;
      case 26: /* create_table ::= createkw temp TABLE ifnotexists nm dbnm */
#line 136 "parse.y"
{
   sqlite3StartTable(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,yymsp[-4].minor.yy194,0,0,yymsp[-2].minor.yy194);
}
#line 2136 "parse.c"
        break;
      case 27: /* createkw ::= CREATE */
#line 139 "parse.y"
{
  pParse->db->lookaside.bEnabled = 0;
  yygotominor.yy0 = yymsp[0].minor.yy0;
}
#line 2144 "parse.c"
        break;
      case 28: /* ifnotexists ::= */
      case 31: /* temp ::= */
      case 70: /* autoinc ::= */
      case 84: /* init_deferred_pred_opt ::= */
      case 86: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
      case 97: /* defer_subclause_opt ::= */
      case 108: /* ifexists ::= */
      case 119: /* distinct ::= ALL */
      case 120: /* distinct ::= */
      case 222: /* between_op ::= BETWEEN */
      case 225: /* in_op ::= IN */
#line 144 "parse.y"
{yygotominor.yy194 = 0;}
#line 2159 "parse.c"
        break;
      case 29: /* ifnotexists ::= IF NOT EXISTS */
      case 30: /* temp ::= TEMP */
      case 71: /* autoinc ::= AUTOINCR */
      case 85: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 107: /* ifexists ::= IF EXISTS */
      case 118: /* distinct ::= DISTINCT */
      case 223: /* between_op ::= NOT BETWEEN */
      case 226: /* in_op ::= NOT IN */
#line 145 "parse.y"
{yygotominor.yy194 = 1;}
#line 2171 "parse.c"
        break;
      case 32: /* create_table_args ::= LP columnlist conslist_opt RP */
#line 151 "parse.y"
{
  sqlite3EndTable(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,0);
}
#line 2178 "parse.c"
        break;
      case 33: /* create_table_args ::= AS select */
#line 154 "parse.y"
{
  sqlite3EndTable(pParse,0,0,yymsp[0].minor.yy243);
  sqlite3SelectDelete(pParse->db, yymsp[0].minor.yy243);
}
#line 2186 "parse.c"
        break;
      case 36: /* column ::= columnid type carglist */
#line 166 "parse.y"
{
  yygotominor.yy0.z = yymsp[-2].minor.yy0.z;
  yygotominor.yy0.n = (int)(pParse->sLastToken.z-yymsp[-2].minor.yy0.z) + pParse->sLastToken.n;
}
#line 2194 "parse.c"
        break;
      case 37: /* columnid ::= nm */
#line 170 "parse.y"
{
  sqlite3AddColumn(pParse,&yymsp[0].minor.yy0);
  yygotominor.yy0 = yymsp[0].minor.yy0;
}
#line 2202 "parse.c"
        break;
      case 38: /* id ::= ID */
      case 39: /* id ::= INDEXED */
      case 40: /* ids ::= ID|STRING */
      case 41: /* nm ::= id */
      case 42: /* nm ::= STRING */
      case 43: /* nm ::= JOIN_KW */
      case 46: /* typetoken ::= typename */
      case 49: /* typename ::= ids */
      case 126: /* as ::= AS nm */
      case 127: /* as ::= ids */
      case 137: /* dbnm ::= DOT nm */
      case 146: /* indexed_opt ::= INDEXED BY nm */
      case 251: /* collate ::= COLLATE ids */
      case 261: /* nmnum ::= plus_num */
      case 262: /* nmnum ::= nm */
      case 263: /* plus_num ::= plus_opt number */
      case 264: /* minus_num ::= MINUS number */
      case 265: /* number ::= INTEGER|FLOAT */
#line 180 "parse.y"
{yygotominor.yy0 = yymsp[0].minor.yy0;}
#line 2224 "parse.c"
        break;
      case 45: /* type ::= typetoken */
#line 242 "parse.y"
{sqlite3AddColumnType(pParse,&yymsp[0].minor.yy0);}
#line 2229 "parse.c"
        break;
      case 47: /* typetoken ::= typename LP signed RP */
#line 244 "parse.y"
{
  yygotominor.yy0.z = yymsp[-3].minor.yy0.z;
  yygotominor.yy0.n = (int)(&yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n] - yymsp[-3].minor.yy0.z);
}
#line 2237 "parse.c"
        break;
      case 48: /* typetoken ::= typename LP signed COMMA signed RP */
#line 248 "parse.y"
{
  yygotominor.yy0.z = yymsp[-5].minor.yy0.z;
  yygotominor.yy0.n = (int)(&yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n] - yymsp[-5].minor.yy0.z);
}
#line 2245 "parse.c"
        break;
      case 50: /* typename ::= typename ids */
#line 254 "parse.y"
{yygotominor.yy0.z=yymsp[-1].minor.yy0.z; yygotominor.yy0.n=yymsp[0].minor.yy0.n+(int)(yymsp[0].minor.yy0.z-yymsp[-1].minor.yy0.z);}
#line 2250 "parse.c"
        break;
      case 57: /* ccons ::= DEFAULT term */
      case 59: /* ccons ::= DEFAULT PLUS term */
#line 265 "parse.y"
{sqlite3AddDefaultValue(pParse,yymsp[0].minor.yy72);}
#line 2256 "parse.c"
        break;
      case 58: /* ccons ::= DEFAULT LP expr RP */
#line 266 "parse.y"
{sqlite3AddDefaultValue(pParse,yymsp[-1].minor.yy72);}
#line 2261 "parse.c"
        break;
      case 60: /* ccons ::= DEFAULT MINUS term */
#line 268 "parse.y"
{
  Expr *p = sqlite3PExpr(pParse, TK_UMINUS, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(p,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
  sqlite3AddDefaultValue(pParse,p);
}
#line 2270 "parse.c"
        break;
      case 61: /* ccons ::= DEFAULT id */
#line 273 "parse.y"
{
  Expr *p = sqlite3PExpr(pParse, TK_STRING, 0, 0, &yymsp[0].minor.yy0);
  sqlite3AddDefaultValue(pParse,p);
}
#line 2278 "parse.c"
        break;
      case 63: /* ccons ::= NOT NULL onconf */
#line 282 "parse.y"
{sqlite3AddNotNull(pParse, yymsp[0].minor.yy194);}
#line 2283 "parse.c"
        break;
      case 64: /* ccons ::= PRIMARY KEY sortorder onconf autoinc */
#line 284 "parse.y"
{sqlite3AddPrimaryKey(pParse,0,yymsp[-1].minor.yy194,yymsp[0].minor.yy194,yymsp[-2].minor.yy194);}
#line 2288 "parse.c"
        break;
      case 65: /* ccons ::= UNIQUE onconf */
#line 285 "parse.y"
{sqlite3CreateIndex(pParse,0,0,0,0,yymsp[0].minor.yy194,0,0,0,0);}
#line 2293 "parse.c"
        break;
      case 66: /* ccons ::= CHECK LP expr RP */
#line 286 "parse.y"
{sqlite3AddCheckConstraint(pParse,yymsp[-1].minor.yy72);}
#line 2298 "parse.c"
        break;
      case 67: /* ccons ::= REFERENCES nm idxlist_opt refargs */
#line 288 "parse.y"
{sqlite3CreateForeignKey(pParse,0,&yymsp[-2].minor.yy0,yymsp[-1].minor.yy148,yymsp[0].minor.yy194);}
#line 2303 "parse.c"
        break;
      case 68: /* ccons ::= defer_subclause */
#line 289 "parse.y"
{sqlite3DeferForeignKey(pParse,yymsp[0].minor.yy194);}
#line 2308 "parse.c"
        break;
      case 69: /* ccons ::= COLLATE ids */
#line 290 "parse.y"
{sqlite3AddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2313 "parse.c"
        break;
      case 72: /* refargs ::= */
#line 303 "parse.y"
{ yygotominor.yy194 = OE_Restrict * 0x010101; }
#line 2318 "parse.c"
        break;
      case 73: /* refargs ::= refargs refarg */
#line 304 "parse.y"
{ yygotominor.yy194 = (yymsp[-1].minor.yy194 & ~yymsp[0].minor.yy497.mask) | yymsp[0].minor.yy497.value; }
#line 2323 "parse.c"
        break;
      case 74: /* refarg ::= MATCH nm */
#line 306 "parse.y"
{ yygotominor.yy497.value = 0;     yygotominor.yy497.mask = 0x000000; }
#line 2328 "parse.c"
        break;
      case 75: /* refarg ::= ON DELETE refact */
#line 307 "parse.y"
{ yygotominor.yy497.value = yymsp[0].minor.yy194;     yygotominor.yy497.mask = 0x0000ff; }
#line 2333 "parse.c"
        break;
      case 76: /* refarg ::= ON UPDATE refact */
#line 308 "parse.y"
{ yygotominor.yy497.value = yymsp[0].minor.yy194<<8;  yygotominor.yy497.mask = 0x00ff00; }
#line 2338 "parse.c"
        break;
      case 77: /* refarg ::= ON INSERT refact */
#line 309 "parse.y"
{ yygotominor.yy497.value = yymsp[0].minor.yy194<<16; yygotominor.yy497.mask = 0xff0000; }
#line 2343 "parse.c"
        break;
      case 78: /* refact ::= SET NULL */
#line 311 "parse.y"
{ yygotominor.yy194 = OE_SetNull; }
#line 2348 "parse.c"
        break;
      case 79: /* refact ::= SET DEFAULT */
#line 312 "parse.y"
{ yygotominor.yy194 = OE_SetDflt; }
#line 2353 "parse.c"
        break;
      case 80: /* refact ::= CASCADE */
#line 313 "parse.y"
{ yygotominor.yy194 = OE_Cascade; }
#line 2358 "parse.c"
        break;
      case 81: /* refact ::= RESTRICT */
#line 314 "parse.y"
{ yygotominor.yy194 = OE_Restrict; }
#line 2363 "parse.c"
        break;
      case 82: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
      case 83: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 98: /* defer_subclause_opt ::= defer_subclause */
      case 100: /* onconf ::= ON CONFLICT resolvetype */
      case 102: /* orconf ::= OR resolvetype */
      case 103: /* resolvetype ::= raisetype */
      case 175: /* insert_cmd ::= INSERT orconf */
#line 316 "parse.y"
{yygotominor.yy194 = yymsp[0].minor.yy194;}
#line 2374 "parse.c"
        break;
      case 87: /* conslist_opt ::= */
#line 326 "parse.y"
{yygotominor.yy0.n = 0; yygotominor.yy0.z = 0;}
#line 2379 "parse.c"
        break;
      case 88: /* conslist_opt ::= COMMA conslist */
#line 327 "parse.y"
{yygotominor.yy0 = yymsp[-1].minor.yy0;}
#line 2384 "parse.c"
        break;
      case 93: /* tcons ::= PRIMARY KEY LP idxlist autoinc RP onconf */
#line 333 "parse.y"
{sqlite3AddPrimaryKey(pParse,yymsp[-3].minor.yy148,yymsp[0].minor.yy194,yymsp[-2].minor.yy194,0);}
#line 2389 "parse.c"
        break;
      case 94: /* tcons ::= UNIQUE LP idxlist RP onconf */
#line 335 "parse.y"
{sqlite3CreateIndex(pParse,0,0,0,yymsp[-2].minor.yy148,yymsp[0].minor.yy194,0,0,0,0);}
#line 2394 "parse.c"
        break;
      case 95: /* tcons ::= CHECK LP expr RP onconf */
#line 336 "parse.y"
{sqlite3AddCheckConstraint(pParse,yymsp[-2].minor.yy72);}
#line 2399 "parse.c"
        break;
      case 96: /* tcons ::= FOREIGN KEY LP idxlist RP REFERENCES nm idxlist_opt refargs defer_subclause_opt */
#line 338 "parse.y"
{
    sqlite3CreateForeignKey(pParse, yymsp[-6].minor.yy148, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy148, yymsp[-1].minor.yy194);
    sqlite3DeferForeignKey(pParse, yymsp[0].minor.yy194);
}
#line 2407 "parse.c"
        break;
      case 99: /* onconf ::= */
      case 101: /* orconf ::= */
#line 352 "parse.y"
{yygotominor.yy194 = OE_Default;}
#line 2413 "parse.c"
        break;
      case 104: /* resolvetype ::= IGNORE */
#line 357 "parse.y"
{yygotominor.yy194 = OE_Ignore;}
#line 2418 "parse.c"
        break;
      case 105: /* resolvetype ::= REPLACE */
      case 176: /* insert_cmd ::= REPLACE */
#line 358 "parse.y"
{yygotominor.yy194 = OE_Replace;}
#line 2424 "parse.c"
        break;
      case 106: /* cmd ::= DROP TABLE ifexists fullname */
#line 362 "parse.y"
{
  sqlite3DropTable(pParse, yymsp[0].minor.yy185, 0, yymsp[-1].minor.yy194);
}
#line 2431 "parse.c"
        break;
      case 109: /* cmd ::= createkw temp VIEW ifnotexists nm dbnm AS select */
#line 372 "parse.y"
{
  sqlite3CreateView(pParse, &yymsp[-7].minor.yy0, &yymsp[-3].minor.yy0, &yymsp[-2].minor.yy0, yymsp[0].minor.yy243, yymsp[-6].minor.yy194, yymsp[-4].minor.yy194);
}
#line 2438 "parse.c"
        break;
      case 110: /* cmd ::= DROP VIEW ifexists fullname */
#line 375 "parse.y"
{
  sqlite3DropTable(pParse, yymsp[0].minor.yy185, 1, yymsp[-1].minor.yy194);
}
#line 2445 "parse.c"
        break;
      case 111: /* cmd ::= select */
#line 382 "parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0};
  sqlite3Select(pParse, yymsp[0].minor.yy243, &dest);
  sqlite3SelectDelete(pParse->db, yymsp[0].minor.yy243);
}
#line 2454 "parse.c"
        break;
      case 112: /* select ::= oneselect */
#line 393 "parse.y"
{yygotominor.yy243 = yymsp[0].minor.yy243;}
#line 2459 "parse.c"
        break;
      case 113: /* select ::= select multiselect_op oneselect */
#line 395 "parse.y"
{
  if( yymsp[0].minor.yy243 ){
    yymsp[0].minor.yy243->op = (u8)yymsp[-1].minor.yy194;
    yymsp[0].minor.yy243->pPrior = yymsp[-2].minor.yy243;
  }else{
    sqlite3SelectDelete(pParse->db, yymsp[-2].minor.yy243);
  }
  yygotominor.yy243 = yymsp[0].minor.yy243;
}
#line 2472 "parse.c"
        break;
      case 115: /* multiselect_op ::= UNION ALL */
#line 406 "parse.y"
{yygotominor.yy194 = TK_ALL;}
#line 2477 "parse.c"
        break;
      case 117: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 410 "parse.y"
{
  yygotominor.yy243 = sqlite3SelectNew(pParse,yymsp[-6].minor.yy148,yymsp[-5].minor.yy185,yymsp[-4].minor.yy72,yymsp[-3].minor.yy148,yymsp[-2].minor.yy72,yymsp[-1].minor.yy148,yymsp[-7].minor.yy194,yymsp[0].minor.yy354.pLimit,yymsp[0].minor.yy354.pOffset);
}
#line 2484 "parse.c"
        break;
      case 121: /* sclp ::= selcollist COMMA */
      case 247: /* idxlist_opt ::= LP idxlist RP */
#line 431 "parse.y"
{yygotominor.yy148 = yymsp[-1].minor.yy148;}
#line 2490 "parse.c"
        break;
      case 122: /* sclp ::= */
      case 150: /* orderby_opt ::= */
      case 158: /* groupby_opt ::= */
      case 240: /* exprlist ::= */
      case 246: /* idxlist_opt ::= */
#line 432 "parse.y"
{yygotominor.yy148 = 0;}
#line 2499 "parse.c"
        break;
      case 123: /* selcollist ::= sclp expr as */
#line 433 "parse.y"
{
   yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-2].minor.yy148,yymsp[-1].minor.yy72,yymsp[0].minor.yy0.n?&yymsp[0].minor.yy0:0);
}
#line 2506 "parse.c"
        break;
      case 124: /* selcollist ::= sclp STAR */
#line 436 "parse.y"
{
  Expr *p = sqlite3PExpr(pParse, TK_ALL, 0, 0, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse, yymsp[-1].minor.yy148, p, 0);
}
#line 2514 "parse.c"
        break;
      case 125: /* selcollist ::= sclp nm DOT STAR */
#line 440 "parse.y"
{
  Expr *pRight = sqlite3PExpr(pParse, TK_ALL, 0, 0, &yymsp[0].minor.yy0);
  Expr *pLeft = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *pDot = sqlite3PExpr(pParse, TK_DOT, pLeft, pRight, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-3].minor.yy148, pDot, 0);
}
#line 2524 "parse.c"
        break;
      case 128: /* as ::= */
#line 453 "parse.y"
{yygotominor.yy0.n = 0;}
#line 2529 "parse.c"
        break;
      case 129: /* from ::= */
#line 465 "parse.y"
{yygotominor.yy185 = sqlite3DbMallocZero(pParse->db, sizeof(*yygotominor.yy185));}
#line 2534 "parse.c"
        break;
      case 130: /* from ::= FROM seltablist */
#line 466 "parse.y"
{
  yygotominor.yy185 = yymsp[0].minor.yy185;
  sqlite3SrcListShiftJoinType(yygotominor.yy185);
}
#line 2542 "parse.c"
        break;
      case 131: /* stl_prefix ::= seltablist joinop */
#line 474 "parse.y"
{
   yygotominor.yy185 = yymsp[-1].minor.yy185;
   if( yygotominor.yy185 && yygotominor.yy185->nSrc>0 ) yygotominor.yy185->a[yygotominor.yy185->nSrc-1].jointype = (u8)yymsp[0].minor.yy194;
}
#line 2550 "parse.c"
        break;
      case 132: /* stl_prefix ::= */
#line 478 "parse.y"
{yygotominor.yy185 = 0;}
#line 2555 "parse.c"
        break;
      case 133: /* seltablist ::= stl_prefix nm dbnm as indexed_opt on_opt using_opt */
#line 479 "parse.y"
{
  yygotominor.yy185 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy185,&yymsp[-5].minor.yy0,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy72,yymsp[0].minor.yy254);
  sqlite3SrcListIndexedBy(pParse, yygotominor.yy185, &yymsp[-2].minor.yy0);
}
#line 2563 "parse.c"
        break;
      case 134: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 485 "parse.y"
{
    yygotominor.yy185 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy185,0,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy243,yymsp[-1].minor.yy72,yymsp[0].minor.yy254);
  }
#line 2570 "parse.c"
        break;
      case 135: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 489 "parse.y"
{
    if( yymsp[-6].minor.yy185==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy72==0 && yymsp[0].minor.yy254==0 ){
      yygotominor.yy185 = yymsp[-4].minor.yy185;
    }else{
      Select *pSubquery;
      sqlite3SrcListShiftJoinType(yymsp[-4].minor.yy185);
      pSubquery = sqlite3SelectNew(pParse,0,yymsp[-4].minor.yy185,0,0,0,0,0,0,0);
      yygotominor.yy185 = sqlite3SrcListAppendFromTerm(pParse,yymsp[-6].minor.yy185,0,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy72,yymsp[0].minor.yy254);
    }
  }
#line 2584 "parse.c"
        break;
      case 136: /* dbnm ::= */
      case 145: /* indexed_opt ::= */
#line 514 "parse.y"
{yygotominor.yy0.z=0; yygotominor.yy0.n=0;}
#line 2590 "parse.c"
        break;
      case 138: /* fullname ::= nm dbnm */
#line 519 "parse.y"
{yygotominor.yy185 = sqlite3SrcListAppend(pParse->db,0,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0);}
#line 2595 "parse.c"
        break;
      case 139: /* joinop ::= COMMA|JOIN */
#line 523 "parse.y"
{ yygotominor.yy194 = JT_INNER; }
#line 2600 "parse.c"
        break;
      case 140: /* joinop ::= JOIN_KW JOIN */
#line 524 "parse.y"
{ yygotominor.yy194 = sqlite3JoinType(pParse,&yymsp[-1].minor.yy0,0,0); }
#line 2605 "parse.c"
        break;
      case 141: /* joinop ::= JOIN_KW nm JOIN */
#line 525 "parse.y"
{ yygotominor.yy194 = sqlite3JoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); }
#line 2610 "parse.c"
        break;
      case 142: /* joinop ::= JOIN_KW nm nm JOIN */
#line 527 "parse.y"
{ yygotominor.yy194 = sqlite3JoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0); }
#line 2615 "parse.c"
        break;
      case 143: /* on_opt ::= ON expr */
      case 154: /* sortitem ::= expr */
      case 161: /* having_opt ::= HAVING expr */
      case 168: /* where_opt ::= WHERE expr */
      case 183: /* expr ::= term */
      case 211: /* escape ::= ESCAPE expr */
      case 235: /* case_else ::= ELSE expr */
      case 237: /* case_operand ::= expr */
#line 531 "parse.y"
{yygotominor.yy72 = yymsp[0].minor.yy72;}
#line 2627 "parse.c"
        break;
      case 144: /* on_opt ::= */
      case 160: /* having_opt ::= */
      case 167: /* where_opt ::= */
      case 212: /* escape ::= */
      case 236: /* case_else ::= */
      case 238: /* case_operand ::= */
#line 532 "parse.y"
{yygotominor.yy72 = 0;}
#line 2637 "parse.c"
        break;
      case 147: /* indexed_opt ::= NOT INDEXED */
#line 547 "parse.y"
{yygotominor.yy0.z=0; yygotominor.yy0.n=1;}
#line 2642 "parse.c"
        break;
      case 148: /* using_opt ::= USING LP inscollist RP */
      case 180: /* inscollist_opt ::= LP inscollist RP */
#line 551 "parse.y"
{yygotominor.yy254 = yymsp[-1].minor.yy254;}
#line 2648 "parse.c"
        break;
      case 149: /* using_opt ::= */
      case 179: /* inscollist_opt ::= */
#line 552 "parse.y"
{yygotominor.yy254 = 0;}
#line 2654 "parse.c"
        break;
      case 151: /* orderby_opt ::= ORDER BY sortlist */
      case 159: /* groupby_opt ::= GROUP BY nexprlist */
      case 239: /* exprlist ::= nexprlist */
#line 563 "parse.y"
{yygotominor.yy148 = yymsp[0].minor.yy148;}
#line 2661 "parse.c"
        break;
      case 152: /* sortlist ::= sortlist COMMA sortitem sortorder */
#line 564 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-3].minor.yy148,yymsp[-1].minor.yy72,0);
  if( yygotominor.yy148 ) yygotominor.yy148->a[yygotominor.yy148->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 2669 "parse.c"
        break;
      case 153: /* sortlist ::= sortitem sortorder */
#line 568 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,0,yymsp[-1].minor.yy72,0);
  if( yygotominor.yy148 && yygotominor.yy148->a ) yygotominor.yy148->a[0].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 2677 "parse.c"
        break;
      case 155: /* sortorder ::= ASC */
      case 157: /* sortorder ::= */
#line 576 "parse.y"
{yygotominor.yy194 = SQLITE_SO_ASC;}
#line 2683 "parse.c"
        break;
      case 156: /* sortorder ::= DESC */
#line 577 "parse.y"
{yygotominor.yy194 = SQLITE_SO_DESC;}
#line 2688 "parse.c"
        break;
      case 162: /* limit_opt ::= */
#line 603 "parse.y"
{yygotominor.yy354.pLimit = 0; yygotominor.yy354.pOffset = 0;}
#line 2693 "parse.c"
        break;
      case 163: /* limit_opt ::= LIMIT expr */
#line 604 "parse.y"
{yygotominor.yy354.pLimit = yymsp[0].minor.yy72; yygotominor.yy354.pOffset = 0;}
#line 2698 "parse.c"
        break;
      case 164: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 606 "parse.y"
{yygotominor.yy354.pLimit = yymsp[-2].minor.yy72; yygotominor.yy354.pOffset = yymsp[0].minor.yy72;}
#line 2703 "parse.c"
        break;
      case 165: /* limit_opt ::= LIMIT expr COMMA expr */
#line 608 "parse.y"
{yygotominor.yy354.pOffset = yymsp[-2].minor.yy72; yygotominor.yy354.pLimit = yymsp[0].minor.yy72;}
#line 2708 "parse.c"
        break;
      case 166: /* cmd ::= DELETE FROM fullname indexed_opt where_opt */
#line 621 "parse.y"
{
  sqlite3SrcListIndexedBy(pParse, yymsp[-2].minor.yy185, &yymsp[-1].minor.yy0);
  sqlite3DeleteFrom(pParse,yymsp[-2].minor.yy185,yymsp[0].minor.yy72);
}
#line 2716 "parse.c"
        break;
      case 169: /* cmd ::= UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 644 "parse.y"
{
  sqlite3SrcListIndexedBy(pParse, yymsp[-4].minor.yy185, &yymsp[-3].minor.yy0);
  sqlite3ExprListCheckLength(pParse,yymsp[-1].minor.yy148,"set list"); 
  sqlite3Update(pParse,yymsp[-4].minor.yy185,yymsp[-1].minor.yy148,yymsp[0].minor.yy72,yymsp[-5].minor.yy194);
}
#line 2725 "parse.c"
        break;
      case 170: /* setlist ::= setlist COMMA nm EQ expr */
#line 655 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy148,yymsp[0].minor.yy72,&yymsp[-2].minor.yy0);}
#line 2730 "parse.c"
        break;
      case 171: /* setlist ::= nm EQ expr */
#line 657 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,0,yymsp[0].minor.yy72,&yymsp[-2].minor.yy0);}
#line 2735 "parse.c"
        break;
      case 172: /* cmd ::= insert_cmd INTO fullname inscollist_opt VALUES LP itemlist RP */
#line 663 "parse.y"
{sqlite3Insert(pParse, yymsp[-5].minor.yy185, yymsp[-1].minor.yy148, 0, yymsp[-4].minor.yy254, yymsp[-7].minor.yy194);}
#line 2740 "parse.c"
        break;
      case 173: /* cmd ::= insert_cmd INTO fullname inscollist_opt select */
#line 665 "parse.y"
{sqlite3Insert(pParse, yymsp[-2].minor.yy185, 0, yymsp[0].minor.yy243, yymsp[-1].minor.yy254, yymsp[-4].minor.yy194);}
#line 2745 "parse.c"
        break;
      case 174: /* cmd ::= insert_cmd INTO fullname inscollist_opt DEFAULT VALUES */
#line 667 "parse.y"
{sqlite3Insert(pParse, yymsp[-3].minor.yy185, 0, 0, yymsp[-2].minor.yy254, yymsp[-5].minor.yy194);}
#line 2750 "parse.c"
        break;
      case 177: /* itemlist ::= itemlist COMMA expr */
      case 241: /* nexprlist ::= nexprlist COMMA expr */
#line 678 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-2].minor.yy148,yymsp[0].minor.yy72,0);}
#line 2756 "parse.c"
        break;
      case 178: /* itemlist ::= expr */
      case 242: /* nexprlist ::= expr */
#line 680 "parse.y"
{yygotominor.yy148 = sqlite3ExprListAppend(pParse,0,yymsp[0].minor.yy72,0);}
#line 2762 "parse.c"
        break;
      case 181: /* inscollist ::= inscollist COMMA nm */
#line 690 "parse.y"
{yygotominor.yy254 = sqlite3IdListAppend(pParse->db,yymsp[-2].minor.yy254,&yymsp[0].minor.yy0);}
#line 2767 "parse.c"
        break;
      case 182: /* inscollist ::= nm */
#line 692 "parse.y"
{yygotominor.yy254 = sqlite3IdListAppend(pParse->db,0,&yymsp[0].minor.yy0);}
#line 2772 "parse.c"
        break;
      case 184: /* expr ::= LP expr RP */
#line 703 "parse.y"
{yygotominor.yy72 = yymsp[-1].minor.yy72; sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); }
#line 2777 "parse.c"
        break;
      case 185: /* term ::= NULL */
      case 190: /* term ::= INTEGER|FLOAT|BLOB */
      case 191: /* term ::= STRING */
#line 704 "parse.y"
{yygotominor.yy72 = sqlite3PExpr(pParse, yymsp[0].major, 0, 0, &yymsp[0].minor.yy0);}
#line 2784 "parse.c"
        break;
      case 186: /* expr ::= id */
      case 187: /* expr ::= JOIN_KW */
#line 705 "parse.y"
{yygotominor.yy72 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);}
#line 2790 "parse.c"
        break;
      case 188: /* expr ::= nm DOT nm */
#line 707 "parse.y"
{
  Expr *temp1 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *temp2 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_DOT, temp1, temp2, 0);
}
#line 2799 "parse.c"
        break;
      case 189: /* expr ::= nm DOT nm DOT nm */
#line 712 "parse.y"
{
  Expr *temp1 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-4].minor.yy0);
  Expr *temp2 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[-2].minor.yy0);
  Expr *temp3 = sqlite3PExpr(pParse, TK_ID, 0, 0, &yymsp[0].minor.yy0);
  Expr *temp4 = sqlite3PExpr(pParse, TK_DOT, temp2, temp3, 0);
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_DOT, temp1, temp4, 0);
}
#line 2810 "parse.c"
        break;
      case 192: /* expr ::= REGISTER */
#line 721 "parse.y"
{yygotominor.yy72 = sqlite3RegisterExpr(pParse, &yymsp[0].minor.yy0);}
#line 2815 "parse.c"
        break;
      case 193: /* expr ::= VARIABLE */
#line 722 "parse.y"
{
  Token *pToken = &yymsp[0].minor.yy0;
  Expr *pExpr = yygotominor.yy72 = sqlite3PExpr(pParse, TK_VARIABLE, 0, 0, pToken);
  sqlite3ExprAssignVarNumber(pParse, pExpr);
}
#line 2824 "parse.c"
        break;
      case 194: /* expr ::= expr COLLATE ids */
#line 727 "parse.y"
{
  yygotominor.yy72 = sqlite3ExprSetColl(pParse, yymsp[-2].minor.yy72, &yymsp[0].minor.yy0);
}
#line 2831 "parse.c"
        break;
      case 195: /* expr ::= CAST LP expr AS typetoken RP */
#line 731 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_CAST, yymsp[-3].minor.yy72, 0, &yymsp[-1].minor.yy0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2839 "parse.c"
        break;
      case 196: /* expr ::= ID LP distinct exprlist RP */
#line 736 "parse.y"
{
  if( yymsp[-1].minor.yy148 && yymsp[-1].minor.yy148->nExpr>SQLITE_MAX_FUNCTION_ARG ){
    sqlite3ErrorMsg(pParse, "too many arguments on function %T", &yymsp[-4].minor.yy0);
  }
  yygotominor.yy72 = sqlite3ExprFunction(pParse, yymsp[-1].minor.yy148, &yymsp[-4].minor.yy0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy194 && yygotominor.yy72 ){
    yygotominor.yy72->flags |= EP_Distinct;
  }
}
#line 2853 "parse.c"
        break;
      case 197: /* expr ::= ID LP STAR RP */
#line 746 "parse.y"
{
  yygotominor.yy72 = sqlite3ExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 2861 "parse.c"
        break;
      case 198: /* term ::= CTIME_KW */
#line 750 "parse.y"
{
  /* The CURRENT_TIME, CURRENT_DATE, and CURRENT_TIMESTAMP values are
  ** treated as functions that return constants */
  yygotominor.yy72 = sqlite3ExprFunction(pParse, 0,&yymsp[0].minor.yy0);
  if( yygotominor.yy72 ){
    yygotominor.yy72->op = TK_CONST_FUNC;  
    yygotominor.yy72->span = yymsp[0].minor.yy0;
  }
}
#line 2874 "parse.c"
        break;
      case 199: /* expr ::= expr AND expr */
      case 200: /* expr ::= expr OR expr */
      case 201: /* expr ::= expr LT|GT|GE|LE expr */
      case 202: /* expr ::= expr EQ|NE expr */
      case 203: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */
      case 204: /* expr ::= expr PLUS|MINUS expr */
      case 205: /* expr ::= expr STAR|SLASH|REM expr */
      case 206: /* expr ::= expr CONCAT expr */
#line 759 "parse.y"
{yygotominor.yy72 = sqlite3PExpr(pParse,yymsp[-1].major,yymsp[-2].minor.yy72,yymsp[0].minor.yy72,0);}
#line 2886 "parse.c"
        break;
      case 207: /* likeop ::= LIKE_KW */
      case 209: /* likeop ::= MATCH */
#line 771 "parse.y"
{yygotominor.yy392.eOperator = yymsp[0].minor.yy0; yygotominor.yy392.not = 0;}
#line 2892 "parse.c"
        break;
      case 208: /* likeop ::= NOT LIKE_KW */
      case 210: /* likeop ::= NOT MATCH */
#line 772 "parse.y"
{yygotominor.yy392.eOperator = yymsp[0].minor.yy0; yygotominor.yy392.not = 1;}
#line 2898 "parse.c"
        break;
      case 213: /* expr ::= expr likeop expr escape */
#line 779 "parse.y"
{
  ExprList *pList;
  pList = sqlite3ExprListAppend(pParse,0, yymsp[-1].minor.yy72, 0);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[-3].minor.yy72, 0);
  if( yymsp[0].minor.yy72 ){
    pList = sqlite3ExprListAppend(pParse,pList, yymsp[0].minor.yy72, 0);
  }
  yygotominor.yy72 = sqlite3ExprFunction(pParse, pList, &yymsp[-2].minor.yy392.eOperator);
  if( yymsp[-2].minor.yy392.not ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72, &yymsp[-3].minor.yy72->span, &yymsp[-1].minor.yy72->span);
  if( yygotominor.yy72 ) yygotominor.yy72->flags |= EP_InfixFunc;
}
#line 2914 "parse.c"
        break;
      case 214: /* expr ::= expr ISNULL|NOTNULL */
#line 792 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, yymsp[0].major, yymsp[-1].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2922 "parse.c"
        break;
      case 215: /* expr ::= expr IS NULL */
#line 796 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_ISNULL, yymsp[-2].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2930 "parse.c"
        break;
      case 216: /* expr ::= expr NOT NULL */
#line 800 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOTNULL, yymsp[-2].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2938 "parse.c"
        break;
      case 217: /* expr ::= expr IS NOT NULL */
#line 804 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOTNULL, yymsp[-3].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-3].minor.yy72->span,&yymsp[0].minor.yy0);
}
#line 2946 "parse.c"
        break;
      case 218: /* expr ::= NOT expr */
      case 219: /* expr ::= BITNOT expr */
#line 808 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, yymsp[-1].major, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
}
#line 2955 "parse.c"
        break;
      case 220: /* expr ::= MINUS expr */
#line 816 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_UMINUS, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
}
#line 2963 "parse.c"
        break;
      case 221: /* expr ::= PLUS expr */
#line 820 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_UPLUS, yymsp[0].minor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy72->span);
}
#line 2971 "parse.c"
        break;
      case 224: /* expr ::= expr between_op expr AND expr */
#line 827 "parse.y"
{
  ExprList *pList = sqlite3ExprListAppend(pParse,0, yymsp[-2].minor.yy72, 0);
  pList = sqlite3ExprListAppend(pParse,pList, yymsp[0].minor.yy72, 0);
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy72, 0, 0);
  if( yygotominor.yy72 ){
    yygotominor.yy72->x.pList = pList;
  }else{
    sqlite3ExprListDelete(pParse->db, pList);
  } 
  if( yymsp[-3].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
  sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy72->span,&yymsp[0].minor.yy72->span);
}
#line 2987 "parse.c"
        break;
      case 227: /* expr ::= expr in_op LP exprlist RP */
#line 843 "parse.y"
{
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_IN, yymsp[-4].minor.yy72, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pList = yymsp[-1].minor.yy148;
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3ExprListDelete(pParse->db, yymsp[-1].minor.yy148);
    }
    if( yymsp[-3].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy72->span,&yymsp[0].minor.yy0);
  }
#line 3002 "parse.c"
        break;
      case 228: /* expr ::= LP select RP */
#line 854 "parse.y"
{
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_SELECT, 0, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pSelect = yymsp[-1].minor.yy243;
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy243);
    }
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0);
  }
#line 3017 "parse.c"
        break;
      case 229: /* expr ::= expr in_op LP select RP */
#line 865 "parse.y"
{
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_IN, yymsp[-4].minor.yy72, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pSelect = yymsp[-1].minor.yy243;
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy243);
    }
    if( yymsp[-3].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-4].minor.yy72->span,&yymsp[0].minor.yy0);
  }
#line 3033 "parse.c"
        break;
      case 230: /* expr ::= expr in_op nm dbnm */
#line 877 "parse.y"
{
    SrcList *pSrc = sqlite3SrcListAppend(pParse->db, 0,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0);
    yygotominor.yy72 = sqlite3PExpr(pParse, TK_IN, yymsp[-3].minor.yy72, 0, 0);
    if( yygotominor.yy72 ){
      yygotominor.yy72->x.pSelect = sqlite3SelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SrcListDelete(pParse->db, pSrc);
    }
    if( yymsp[-2].minor.yy194 ) yygotominor.yy72 = sqlite3PExpr(pParse, TK_NOT, yygotominor.yy72, 0, 0);
    sqlite3ExprSpan(yygotominor.yy72,&yymsp[-3].minor.yy72->span,yymsp[0].minor.yy0.z?&yymsp[0].minor.yy0:&yymsp[-1].minor.yy0);
  }
#line 3050 "parse.c"
        break;
      case 231: /* expr ::= EXISTS LP select RP */
#line 890 "parse.y"
{
    Expr *p = yygotominor.yy72 = sqlite3PExpr(pParse, TK_EXISTS, 0, 0, 0);
    if( p ){
      p->x.pSelect = yymsp[-1].minor.yy243;
      ExprSetProperty(yygotominor.yy72, EP_xIsSelect);
      sqlite3ExprSpan(p,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
      sqlite3ExprSetHeight(pParse, yygotominor.yy72);
    }else{
      sqlite3SelectDelete(pParse->db, yymsp[-1].minor.yy243);
    }
  }
#line 3065 "parse.c"
        break;
      case 232: /* expr ::= CASE case_operand case_exprlist case_else END */
#line 904 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_CASE, yymsp[-3].minor.yy72, yymsp[-1].minor.yy72, 0);
  if( yygotominor.yy72 ){
    yygotominor.yy72->x.pList = yymsp[-2].minor.yy148;
    sqlite3ExprSetHeight(pParse, yygotominor.yy72);
  }else{
    sqlite3ExprListDelete(pParse->db, yymsp[-2].minor.yy148);
  }
  sqlite3ExprSpan(yygotominor.yy72, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3079 "parse.c"
        break;
      case 233: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 916 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy148, yymsp[-2].minor.yy72, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yygotominor.yy148, yymsp[0].minor.yy72, 0);
}
#line 3087 "parse.c"
        break;
      case 234: /* case_exprlist ::= WHEN expr THEN expr */
#line 920 "parse.y"
{
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,0, yymsp[-2].minor.yy72, 0);
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yygotominor.yy148, yymsp[0].minor.yy72, 0);
}
#line 3095 "parse.c"
        break;
      case 243: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm dbnm ON nm LP idxlist RP */
#line 949 "parse.y"
{
  sqlite3CreateIndex(pParse, &yymsp[-6].minor.yy0, &yymsp[-5].minor.yy0, 
                     sqlite3SrcListAppend(pParse->db,0,&yymsp[-3].minor.yy0,0), yymsp[-1].minor.yy148, yymsp[-9].minor.yy194,
                      &yymsp[-10].minor.yy0, &yymsp[0].minor.yy0, SQLITE_SO_ASC, yymsp[-7].minor.yy194);
}
#line 3104 "parse.c"
        break;
      case 244: /* uniqueflag ::= UNIQUE */
      case 291: /* raisetype ::= ABORT */
#line 956 "parse.y"
{yygotominor.yy194 = OE_Abort;}
#line 3110 "parse.c"
        break;
      case 245: /* uniqueflag ::= */
#line 957 "parse.y"
{yygotominor.yy194 = OE_None;}
#line 3115 "parse.c"
        break;
      case 248: /* idxlist ::= idxlist COMMA nm collate sortorder */
#line 966 "parse.y"
{
  Expr *p = 0;
  if( yymsp[-1].minor.yy0.n>0 ){
    p = sqlite3PExpr(pParse, TK_COLUMN, 0, 0, 0);
    sqlite3ExprSetColl(pParse, p, &yymsp[-1].minor.yy0);
  }
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,yymsp[-4].minor.yy148, p, &yymsp[-2].minor.yy0);
  sqlite3ExprListCheckLength(pParse, yygotominor.yy148, "index");
  if( yygotominor.yy148 ) yygotominor.yy148->a[yygotominor.yy148->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 3129 "parse.c"
        break;
      case 249: /* idxlist ::= nm collate sortorder */
#line 976 "parse.y"
{
  Expr *p = 0;
  if( yymsp[-1].minor.yy0.n>0 ){
    p = sqlite3PExpr(pParse, TK_COLUMN, 0, 0, 0);
    sqlite3ExprSetColl(pParse, p, &yymsp[-1].minor.yy0);
  }
  yygotominor.yy148 = sqlite3ExprListAppend(pParse,0, p, &yymsp[-2].minor.yy0);
  sqlite3ExprListCheckLength(pParse, yygotominor.yy148, "index");
  if( yygotominor.yy148 ) yygotominor.yy148->a[yygotominor.yy148->nExpr-1].sortOrder = (u8)yymsp[0].minor.yy194;
}
#line 3143 "parse.c"
        break;
      case 250: /* collate ::= */
#line 988 "parse.y"
{yygotominor.yy0.z = 0; yygotominor.yy0.n = 0;}
#line 3148 "parse.c"
        break;
      case 252: /* cmd ::= DROP INDEX ifexists fullname */
#line 994 "parse.y"
{sqlite3DropIndex(pParse, yymsp[0].minor.yy185, yymsp[-1].minor.yy194);}
#line 3153 "parse.c"
        break;
      case 253: /* cmd ::= VACUUM */
      case 254: /* cmd ::= VACUUM nm */
#line 1000 "parse.y"
{sqlite3Vacuum(pParse);}
#line 3159 "parse.c"
        break;
      case 255: /* cmd ::= PRAGMA nm dbnm EQ nmnum */
      case 256: /* cmd ::= PRAGMA nm dbnm EQ ON */
      case 257: /* cmd ::= PRAGMA nm dbnm EQ DELETE */
#line 1009 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,0);}
#line 3166 "parse.c"
        break;
      case 258: /* cmd ::= PRAGMA nm dbnm EQ minus_num */
#line 1012 "parse.y"
{
  sqlite3Pragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0,1);
}
#line 3173 "parse.c"
        break;
      case 259: /* cmd ::= PRAGMA nm dbnm LP nmnum RP */
#line 1015 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);}
#line 3178 "parse.c"
        break;
      case 260: /* cmd ::= PRAGMA nm dbnm */
#line 1016 "parse.y"
{sqlite3Pragma(pParse,&yymsp[-1].minor.yy0,&yymsp[0].minor.yy0,0,0);}
#line 3183 "parse.c"
        break;
      case 268: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1031 "parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  sqlite3FinishTrigger(pParse, yymsp[-1].minor.yy145, &all);
}
#line 3193 "parse.c"
        break;
      case 269: /* trigger_decl ::= temp TRIGGER ifnotexists nm dbnm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1040 "parse.y"
{
  sqlite3BeginTrigger(pParse, &yymsp[-7].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy194, yymsp[-4].minor.yy332.a, yymsp[-4].minor.yy332.b, yymsp[-2].minor.yy185, yymsp[0].minor.yy72, yymsp[-10].minor.yy194, yymsp[-8].minor.yy194);
  yygotominor.yy0 = (yymsp[-6].minor.yy0.n==0?yymsp[-7].minor.yy0:yymsp[-6].minor.yy0);
}
#line 3201 "parse.c"
        break;
      case 270: /* trigger_time ::= BEFORE */
      case 273: /* trigger_time ::= */
#line 1046 "parse.y"
{ yygotominor.yy194 = TK_BEFORE; }
#line 3207 "parse.c"
        break;
      case 271: /* trigger_time ::= AFTER */
#line 1047 "parse.y"
{ yygotominor.yy194 = TK_AFTER;  }
#line 3212 "parse.c"
        break;
      case 272: /* trigger_time ::= INSTEAD OF */
#line 1048 "parse.y"
{ yygotominor.yy194 = TK_INSTEAD;}
#line 3217 "parse.c"
        break;
      case 274: /* trigger_event ::= DELETE|INSERT */
      case 275: /* trigger_event ::= UPDATE */
#line 1053 "parse.y"
{yygotominor.yy332.a = yymsp[0].major; yygotominor.yy332.b = 0;}
#line 3223 "parse.c"
        break;
      case 276: /* trigger_event ::= UPDATE OF inscollist */
#line 1055 "parse.y"
{yygotominor.yy332.a = TK_UPDATE; yygotominor.yy332.b = yymsp[0].minor.yy254;}
#line 3228 "parse.c"
        break;
      case 279: /* when_clause ::= */
      case 296: /* key_opt ::= */
#line 1062 "parse.y"
{ yygotominor.yy72 = 0; }
#line 3234 "parse.c"
        break;
      case 280: /* when_clause ::= WHEN expr */
      case 297: /* key_opt ::= KEY expr */
#line 1063 "parse.y"
{ yygotominor.yy72 = yymsp[0].minor.yy72; }
#line 3240 "parse.c"
        break;
      case 281: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1067 "parse.y"
{
/*
  if( yymsp[-2].minor.yy145 ){
    yymsp[-2].minor.yy145->pLast->pNext = yymsp[-1].minor.yy145;
  }else{
    yymsp[-2].minor.yy145 = yymsp[-1].minor.yy145;
  }
*/
  assert( yymsp[-2].minor.yy145!=0 );
  yymsp[-2].minor.yy145->pLast->pNext = yymsp[-1].minor.yy145;
  yymsp[-2].minor.yy145->pLast = yymsp[-1].minor.yy145;
  yygotominor.yy145 = yymsp[-2].minor.yy145;
}
#line 3257 "parse.c"
        break;
      case 282: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1080 "parse.y"
{ 
  /* if( yymsp[-1].minor.yy145 ) */
  assert( yymsp[-1].minor.yy145!=0 );
  yymsp[-1].minor.yy145->pLast = yymsp[-1].minor.yy145;
  yygotominor.yy145 = yymsp[-1].minor.yy145;
}
#line 3267 "parse.c"
        break;
      case 283: /* trigger_cmd ::= UPDATE orconf nm SET setlist where_opt */
#line 1091 "parse.y"
{ yygotominor.yy145 = sqlite3TriggerUpdateStep(pParse->db, &yymsp[-3].minor.yy0, yymsp[-1].minor.yy148, yymsp[0].minor.yy72, yymsp[-4].minor.yy194); }
#line 3272 "parse.c"
        break;
      case 284: /* trigger_cmd ::= insert_cmd INTO nm inscollist_opt VALUES LP itemlist RP */
#line 1096 "parse.y"
{yygotominor.yy145 = sqlite3TriggerInsertStep(pParse->db, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy254, yymsp[-1].minor.yy148, 0, yymsp[-7].minor.yy194);}
#line 3277 "parse.c"
        break;
      case 285: /* trigger_cmd ::= insert_cmd INTO nm inscollist_opt select */
#line 1099 "parse.y"
{yygotominor.yy145 = sqlite3TriggerInsertStep(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy254, 0, yymsp[0].minor.yy243, yymsp[-4].minor.yy194);}
#line 3282 "parse.c"
        break;
      case 286: /* trigger_cmd ::= DELETE FROM nm where_opt */
#line 1103 "parse.y"
{yygotominor.yy145 = sqlite3TriggerDeleteStep(pParse->db, &yymsp[-1].minor.yy0, yymsp[0].minor.yy72);}
#line 3287 "parse.c"
        break;
      case 287: /* trigger_cmd ::= select */
#line 1106 "parse.y"
{yygotominor.yy145 = sqlite3TriggerSelectStep(pParse->db, yymsp[0].minor.yy243); }
#line 3292 "parse.c"
        break;
      case 288: /* expr ::= RAISE LP IGNORE RP */
#line 1109 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_RAISE, 0, 0, 0); 
  if( yygotominor.yy72 ){
    yygotominor.yy72->affinity = OE_Ignore;
    sqlite3ExprSpan(yygotominor.yy72, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
  }
}
#line 3303 "parse.c"
        break;
      case 289: /* expr ::= RAISE LP raisetype COMMA nm RP */
#line 1116 "parse.y"
{
  yygotominor.yy72 = sqlite3PExpr(pParse, TK_RAISE, 0, 0, &yymsp[-1].minor.yy0); 
  if( yygotominor.yy72 ) {
    yygotominor.yy72->affinity = (char)yymsp[-3].minor.yy194;
    sqlite3ExprSpan(yygotominor.yy72, &yymsp[-5].minor.yy0, &yymsp[0].minor.yy0);
  }
}
#line 3314 "parse.c"
        break;
      case 290: /* raisetype ::= ROLLBACK */
#line 1126 "parse.y"
{yygotominor.yy194 = OE_Rollback;}
#line 3319 "parse.c"
        break;
      case 292: /* raisetype ::= FAIL */
#line 1128 "parse.y"
{yygotominor.yy194 = OE_Fail;}
#line 3324 "parse.c"
        break;
      case 293: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1133 "parse.y"
{
  sqlite3DropTrigger(pParse,yymsp[0].minor.yy185,yymsp[-1].minor.yy194);
}
#line 3331 "parse.c"
        break;
      case 294: /* cmd ::= ATTACH database_kw_opt expr AS expr key_opt */
#line 1140 "parse.y"
{
  sqlite3Attach(pParse, yymsp[-3].minor.yy72, yymsp[-1].minor.yy72, yymsp[0].minor.yy72);
}
#line 3338 "parse.c"
        break;
      case 295: /* cmd ::= DETACH database_kw_opt expr */
#line 1143 "parse.y"
{
  sqlite3Detach(pParse, yymsp[0].minor.yy72);
}
#line 3345 "parse.c"
        break;
      case 300: /* cmd ::= REINDEX */
#line 1158 "parse.y"
{sqlite3Reindex(pParse, 0, 0);}
#line 3350 "parse.c"
        break;
      case 301: /* cmd ::= REINDEX nm dbnm */
#line 1159 "parse.y"
{sqlite3Reindex(pParse, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);}
#line 3355 "parse.c"
        break;
      case 302: /* cmd ::= ANALYZE */
#line 1164 "parse.y"
{sqlite3Analyze(pParse, 0, 0);}
#line 3360 "parse.c"
        break;
      case 303: /* cmd ::= ANALYZE nm dbnm */
#line 1165 "parse.y"
{sqlite3Analyze(pParse, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy0);}
#line 3365 "parse.c"
        break;
      case 304: /* cmd ::= ALTER TABLE fullname RENAME TO nm */
#line 1170 "parse.y"
{
  sqlite3AlterRenameTable(pParse,yymsp[-3].minor.yy185,&yymsp[0].minor.yy0);
}
#line 3372 "parse.c"
        break;
      case 305: /* cmd ::= ALTER TABLE add_column_fullname ADD kwcolumn_opt column */
#line 1173 "parse.y"
{
  sqlite3AlterFinishAddColumn(pParse, &yymsp[0].minor.yy0);
}
#line 3379 "parse.c"
        break;
      case 306: /* add_column_fullname ::= fullname */
#line 1176 "parse.y"
{
  pParse->db->lookaside.bEnabled = 0;
  sqlite3AlterBeginAddColumn(pParse, yymsp[0].minor.yy185);
}
#line 3387 "parse.c"
        break;
      case 309: /* cmd ::= create_vtab */
#line 1186 "parse.y"
{sqlite3VtabFinishParse(pParse,0);}
#line 3392 "parse.c"
        break;
      case 310: /* cmd ::= create_vtab LP vtabarglist RP */
#line 1187 "parse.y"
{sqlite3VtabFinishParse(pParse,&yymsp[0].minor.yy0);}
#line 3397 "parse.c"
        break;
      case 311: /* create_vtab ::= createkw VIRTUAL TABLE nm dbnm USING nm */
#line 1188 "parse.y"
{
    sqlite3VtabBeginParse(pParse, &yymsp[-3].minor.yy0, &yymsp[-2].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3404 "parse.c"
        break;
      case 314: /* vtabarg ::= */
#line 1193 "parse.y"
{sqlite3VtabArgInit(pParse);}
#line 3409 "parse.c"
        break;
      case 316: /* vtabargtoken ::= ANY */
      case 317: /* vtabargtoken ::= lp anylist RP */
      case 318: /* lp ::= LP */
      case 320: /* anylist ::= anylist ANY */
#line 1195 "parse.y"
{sqlite3VtabArgExtend(pParse,&yymsp[0].minor.yy0);}
#line 3417 "parse.c"
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = (YYACTIONTYPE)yyact;
      yymsp->major = (YYCODETYPE)yygoto;
      yymsp->minor = yygotominor;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlite3ParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  sqlite3ParserARG_FETCH;
#define TOKEN (yyminor.yy0)
#line 34 "parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  sqlite3ErrorMsg(pParse, "near \"%T\": syntax error", &TOKEN);
  pParse->parseError = 1;
#line 3481 "parse.c"
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlite3ParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  sqlite3ParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlite3ParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlite3Parser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlite3ParserTOKENTYPE yyminor       /* The value for the token */
  sqlite3ParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      /*memset(&yyminorunion, 0, sizeof(yyminorunion));*/
      yyminorunion = yyzerominor;
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);
  sqlite3ParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact<YYNSTATE ){
      assert( !yyendofinput );  /* Impossible to shift the $ token */
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}
